@@ -25,12 +25,11 @@ typedef double (*gamgi_angular) (double x, double y, double z, double r);
 /********** enumerations **********
  **********************************/
 
-/****************************************************************
- * external GAMGI enumerations start at 1 and share FALSE for 0 *
- ****************************************************************/
+/**************************************************************
+ * All external enumerations start at 1 and share FALSE for 0 *
+ **************************************************************/
 
-enum { GAMGI_CHEM_AXES_NONE = 1, GAMGI_CHEM_AXES_UNIT,
-GAMGI_CHEM_AXES_BOHR, GAMGI_CHEM_AXES_FRAME };
+enum { GAMGI_CHEM_UNIT = 1, GAMGI_CHEM_BOHR, GAMGI_CHEM_RADIUS };
 
 /************* macros ************
  *********************************/
@@ -184,13 +183,16 @@ GAMGI_CHEM_FILTER_IDENTICAL, GAMGI_CHEM_FILTER_NONE };
 #define GAMGI_CHEM_ATOM_SIZE 0.8
 #define GAMGI_CHEM_BOND_SIZE 0.5
 
-/*************************************************
- * Atom Temperature: 273.15 Kelvin = 0 Celsius   *
- * (Current IUPAC standard temperature), used in *
- * Diffraction Analysis, in Debye-Waller factors *
- *************************************************/
+/****************************************************
+ * Atom temperature (X-Ray Debye-Waller factor),    *
+ * measured in Angstrom squared (A**2): 0 < T < 100 *
+ * Generally, T < 30 signifies confidence in its    *
+ * position, while T > 60 signifies disorder.       *
+ ****************************************************/
 
-#define GAMGI_CHEM_ATOM_TEMPERATURE 273.15
+#define GAMGI_CHEM_ATOM_TEMPERATURE_MIN   0.0
+#define GAMGI_CHEM_ATOM_TEMPERATURE_MAX 100.0
+#define GAMGI_CHEM_ATOM_TEMPERATURE GAMGI_CHEM_ATOM_TEMPERATURE_MIN
 
 /***********************
  * default atom origin *
