@@ -15,7 +15,6 @@
 #include "gamgi_global.h"
 
 #include "gamgi_engine_remove.h"
-#include "gamgi_engine_unlink.h"
 #include "gamgi_engine_reparent.h"
 #include "gamgi_math_hash.h"
 #include "gamgi_chem_property.h"
@@ -644,84 +643,6 @@ while (i <= end)
 
 }
 
-gamgi_bool gamgi_chem_atom_unlink (gamgi_atom *atom)
-{
-gamgi_object *parent;
-gamgi_plane *plane;
-gamgi_direction *direction;
-gamgi_atom *atom1, *atom2, *atom3;
-
-parent = atom->object.object;
-
-/*******************************************************
- * This atom is about to be removed or linked to a     *
- * different object, so if it is currently defining    *
- * a plane or direction, remove the plane or direction *
- *******************************************************/
-
-if (parent->class == GAMGI_ENGINE_PLANE)
-  {
-  plane = GAMGI_CAST_PLANE parent;
-  if (plane->reference == GAMGI_ENGINE_ATOM &&
-  gamgi_phys_plane_reference (plane, &atom1, &atom2, &atom3) == TRUE &&
-  (atom == atom1 || atom == atom2 || atom == atom3))
-    {
-    /*************************************
-     * unlink atom before removing plane *
-     *************************************/
-
-    gamgi_engine_unlink_atom (atom);
-    
-    /***********************************************************
-     * link plane child to plane parent, before removing plane *
-     ***********************************************************/
-
-    parent = plane->object.object;
-    gamgi_engine_reparent_direction (plane->direction_start, parent);
-    gamgi_engine_reparent_atom (plane->atom_start, parent);
-    gamgi_engine_reparent_orbital (plane->orbital_start, parent);
-    gamgi_engine_reparent_text (plane->text_start, parent);
-
-    gamgi_engine_unlink_plane (plane);
-    gamgi_engine_remove_plane (plane);
-    return TRUE;
-    }
-
-  }
-
-if (parent->class == GAMGI_ENGINE_DIRECTION)
-  {
-  direction = GAMGI_CAST_DIRECTION parent;
-  if (direction->reference == GAMGI_ENGINE_ATOM &&
-  gamgi_phys_direction_reference (direction, &atom1, &atom2) == TRUE &&
-  (atom == atom1 || atom == atom2))
-    {
-    /*****************************************
-     * unlink atom before removing direction *
-     *****************************************/
-
-    gamgi_engine_unlink_atom (atom);
-
-    /***********************************************************************
-     * link direction child to direction parent, before removing direction *
-     ***********************************************************************/
-
-    parent = direction->object.object;
-    gamgi_engine_reparent_atom (direction->atom_start, parent);
-    gamgi_engine_reparent_orbital (direction->orbital_start, parent);
-    gamgi_engine_reparent_text (direction->text_start, parent);
-
-    gamgi_engine_unlink_direction (direction);
-    gamgi_engine_remove_direction (direction);
-    return TRUE;
-    }
-
-  }
-
-gamgi_engine_unlink_atom (atom);
-return FALSE;
-}
-
 void gamgi_chem_atom_clean (gamgi_atom *atom)
 {
 gamgi_bond *bond;
