@@ -184,7 +184,7 @@ int sampling, seed;
 
 gamgi_bool phase, frame;
 int octants[8];
-double axes;
+gamgi_enum axes;
 
 /**************
  * array data *
@@ -274,10 +274,10 @@ typedef struct _gamgi_direction {
 gamgi_object object;
 
 void (*draw) (struct _gamgi_direction *);
-void (*projection) (double *, double *);
+void (*net) (double *, double *);
 
 gamgi_enum reference;
-gamgi_enum type;
+gamgi_enum model;
 
 int uvw[3];
 gamgi_enum vectors;
@@ -310,10 +310,10 @@ typedef struct _gamgi_plane {
 gamgi_object object;
 
 void (*draw) (struct _gamgi_plane *);
-void (*projection) (double *, double *);
+void (*net) (double *, double *);
 
 gamgi_enum reference;
-gamgi_enum type;
+gamgi_enum model;
 
 int hkl[3];
 gamgi_enum vectors;
@@ -459,7 +459,7 @@ double a1[3], a2[3], a3[3];
 double p1[3], p2[3], p3[3]; 
 double v1, v2, v3, v12, v13, v23;
 double reciprocal;
-gamgi_enum lattice, type, borders;
+gamgi_enum lattice, model, borders;
 gamgi_bool faces, nodes;
 int group, n1, n2, n3; 
 
@@ -828,9 +828,9 @@ typedef void (* gamgi_function2) (gamgi_object *object, void *data);
 /********** enumerations **********
  **********************************/
 
-/************************************************************
- * All GAMGI enumerations start at 1 and share FALSE for 0. *
- ************************************************************/
+/**************************************************************
+ * All external enumerations start at 1 and share FALSE for 0 *
+ **************************************************************/
 
 enum {GAMGI_ENGINE_HELP = 1, GAMGI_ENGINE_TEXT, GAMGI_ENGINE_ORBITAL,
 GAMGI_ENGINE_BOND, GAMGI_ENGINE_ATOM, GAMGI_ENGINE_DIRECTION, GAMGI_ENGINE_PLANE,
