@@ -217,10 +217,10 @@ gamgi_direction *direction_new)
 int i;
 
 static_copy (GAMGI_CAST_OBJECT direction, GAMGI_CAST_OBJECT direction_new);
-direction_new->projection = direction->projection;
+direction_new->net = direction->net;
 direction_new->draw = direction->draw;
 direction_new->reference = direction->reference;
-direction_new->type = direction->type;
+direction_new->model = direction->model;
 
 /*****************************
  * copy description: indices *
@@ -288,10 +288,10 @@ void gamgi_engine_copy_out_plane (gamgi_plane *plane, gamgi_plane *plane_new)
 int i;
 
 static_copy (GAMGI_CAST_OBJECT plane, GAMGI_CAST_OBJECT plane_new);
-plane_new->projection = plane->projection;
+plane_new->net = plane->net;
 plane_new->draw = plane->draw;
 plane_new->reference = plane->reference;
-plane_new->type = plane->type;
+plane_new->model = plane->model;
 
 /*****************************
  * copy description: indices *
@@ -578,7 +578,7 @@ cell_new->n_nodes = cell->n_nodes;
  * copy volume data: number of cells, volume parameters *
  ********************************************************/
 
-cell_new->type = cell->type;
+cell_new->model = cell->model;
 
 cell_new->n1 = cell->n1;
 cell_new->n2 = cell->n2;
