@@ -850,9 +850,14 @@ gamgi->layer = gamgi_global_create_layer ();
 gamgi->window = gamgi_global_create_window ();
 gamgi->gamgi = gamgi_global_create_gamgi ();
 
-/***********************************************
- * initialize object selection lists, pointers *
- ***********************************************/
+/***************************************************
+ * initialize object selection tools, lists, focus *
+ ***************************************************/
+
+gamgi->function = NULL;
+gamgi->window_dialog = NULL;
+gamgi->window_mouse = NULL;
+gamgi->state = FALSE;
 
 gamgi->texts = NULL;
 gamgi->orbitals = NULL;
@@ -872,10 +877,7 @@ gamgi->lights = NULL;
 gamgi->layers = NULL;
 gamgi->windows = NULL;
 
-gamgi->function = NULL;
-gamgi->window_dialog = NULL;
-gamgi->window_mouse = NULL;
-gamgi->state = FALSE;
+gamgi->focus = FALSE;
 
 /**********************************
  * initialise pointers to objects *
