@@ -120,7 +120,7 @@ orbital->seed = 0;
 orbital->phase = FALSE;
 orbital->frame = FALSE;
 for (i = 0; i < 8; i++) orbital->octants[i] = 0;
-orbital->axes = 0.0;
+orbital->axes = FALSE;
 
 orbital->dots[0] = 0;
 orbital->dots[1] = 0;
@@ -260,8 +260,8 @@ direction->quaternion[2] = 0.0;
 direction->quaternion[3] = 1.0;
 
 direction->draw = NULL;
-direction->projection = NULL;
-direction->type = FALSE;
+direction->net = NULL;
+direction->model = FALSE;
 
 direction->points = NULL;
 direction->loops = NULL;
@@ -312,8 +312,8 @@ plane->quaternion[2] = 0.0;
 plane->quaternion[3] = 1.0;
 
 plane->draw = NULL;
-plane->projection = NULL;
-plane->type = FALSE;
+plane->net = NULL;
+plane->model = FALSE;
 
 plane->points = NULL;
 plane->loops = NULL;
@@ -501,7 +501,7 @@ cell->quaternion[1] = 0.0;
 cell->quaternion[2] = 0.0;
 cell->quaternion[3] = 1.0;
 
-cell->type = FALSE;
+cell->model = FALSE;
 
 cell->n1 = 1;
 cell->n2 = 1;
