@@ -949,7 +949,7 @@ while (dlist != NULL)
  * write cdata: each point has 3 coordinates x,y,z *
  ***************************************************/
 
-if (plane->type == GAMGI_PHYS_POLYGON)
+if (plane->model == GAMGI_PHYS_POLYGON)
   {
   static_cdata ("points", "double", 3 * plane->n_points,
   plane->points, window, fp, depth, depth_last, error);
