@@ -355,7 +355,7 @@ int column;
 if (fabs (atom_class->temperature - GAMGI_CHEM_ATOM_TEMPERATURE) > GAMGI_MATH_TOLERANCE)
   {
   sprintf (string, "temperature=\"%.*f\"",
-  GAMGI_MATH_DECIMAL_TEMPERATURE, atom_class->temperature);
+  GAMGI_MATH_DECIMAL_OCCUPANCY, atom_class->temperature);
   gamgi_expat_export_element (fp, "<atom", string,
   depth_parent, depth_last, &column, output, error);
   }
