@@ -336,11 +336,12 @@ if (strcmp (token, "11111111") != 0)
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
-if (orbital->axes > 0.0)
-  {
-  sprintf (string, "axes=\"%.*f\"", gamgi->gamgi->length, orbital->axes);
-  gamgi_expat_export_attribute (fp, string, depth, column, error);
-  }
+if (orbital->axes == GAMGI_CHEM_UNIT)
+  gamgi_expat_export_attribute (fp, "axes=\"unit\"", depth, column, error);
+else if (orbital->axes == GAMGI_CHEM_BOHR)
+  gamgi_expat_export_attribute (fp, "axes=\"bohr\"", depth, column, error);
+else if (orbital->axes == GAMGI_CHEM_RADIUS)
+  gamgi_expat_export_attribute (fp, "axes=\"radius\"", depth, column, error);
 
 /*************************************
  * origin: x,y,z (optional, coupled) *
@@ -664,7 +665,7 @@ if (fabs (atom->charge - GAMGI_CHEM_ATOM_CHARGE) > GAMGI_MATH_TOLERANCE)
 if (fabs (atom->temperature - gamgi->atom->temperature) > GAMGI_MATH_TOLERANCE)
   {
   sprintf (string, "temperature=\"%.*f\"", 
-  GAMGI_MATH_DECIMAL_TEMPERATURE, atom->temperature);
+  GAMGI_MATH_DECIMAL_OCCUPANCY, atom->temperature);
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
@@ -807,17 +808,16 @@ if (direction->reference == GAMGI_ENGINE_CELL)
     gamgi_expat_export_attribute (fp, string, depth, column, error);
     }
 
-  /*************************
-   * projection (optional) *
-   *************************/
+  /*****************************
+   * projection net (optional) *
+   *****************************/
 
-  if (direction->projection != NULL && 
-  direction->projection != GAMGI_PHYS_CELL_PROJECTION)
+  if (direction->net != NULL && direction->net != GAMGI_PHYS_PROJECTION_NET)
     {
-    if (direction->projection == gamgi_phys_projection_wulff)
-      sprintf (string, "projection=\"wulff\"");
-    if (direction->projection == gamgi_phys_projection_schmidt)
-      sprintf (string, "projection=\"schmidt\"");
+    if (direction->net == gamgi_phys_projection_wulff)
+      sprintf (string, "net=\"wulff\"");
+    if (direction->net == gamgi_phys_projection_schmidt)
+      sprintf (string, "net=\"schmidt\"");
     gamgi_expat_export_attribute (fp, string, depth, column, error);
     }
 
@@ -826,9 +826,9 @@ if (direction->reference == GAMGI_ENGINE_CELL)
    * pole is default for 2D projection *
    *************************************/
 
-  if (direction->type == GAMGI_PHYS_TRACE)
+  if (direction->model == GAMGI_PHYS_TRACE)
     {
-    sprintf (string, "type=\"trace\"");
+    sprintf (string, "model=\"trace\"");
     gamgi_expat_export_attribute (fp, string, depth, column, error);
     }
 
@@ -872,7 +872,7 @@ if (direction->reference == GAMGI_ENGINE_CELL)
  * initial,final x,y,z points (required, coupled) *
  **************************************************/
 
-if (direction->type == GAMGI_PHYS_LINE)
+if (direction->model == GAMGI_PHYS_LINE)
   {
   sprintf (string, "begin_x=\"%.*f\"", gamgi->gamgi->length, direction->points[0]);
   gamgi_expat_export_attribute (fp, string, depth, column, error);
@@ -1060,16 +1060,16 @@ if (plane->reference == GAMGI_ENGINE_CELL)
     gamgi_expat_export_attribute (fp, string, depth, column, error);
     }
 
-  /*************************
-   * projection (optional) *
-   *************************/
+  /*****************************
+   * projection net (optional) *
+   *****************************/
 
-  if (plane->projection != NULL && plane->projection != GAMGI_PHYS_CELL_PROJECTION)
+  if (plane->net != NULL && plane->net != GAMGI_PHYS_PROJECTION_NET)
     {
-    if (plane->projection == gamgi_phys_projection_wulff)
-      sprintf (string, "projection=\"wulff\"");
-    if (plane->projection == gamgi_phys_projection_schmidt)
-      sprintf (string, "projection=\"schmidt\"");
+    if (plane->net == gamgi_phys_projection_wulff)
+      sprintf (string, "net=\"wulff\"");
+    if (plane->net == gamgi_phys_projection_schmidt)
+      sprintf (string, "net=\"schmidt\"");
     gamgi_expat_export_attribute (fp, string, depth, column, error);
     }
 
@@ -1078,15 +1078,15 @@ if (plane->reference == GAMGI_ENGINE_CELL)
    * pole is default for 2D projection *
    *************************************/
 
-  if (plane->type == GAMGI_PHYS_TRACE)
+  if (plane->model == GAMGI_PHYS_TRACE)
     {
-    sprintf (string, "type=\"trace\"");
+    sprintf (string, "model=\"trace\"");
     gamgi_expat_export_attribute (fp, string, depth, column, error);
     }
 
-  if (plane->type == GAMGI_PHYS_VECTOR)
+  if (plane->model == GAMGI_PHYS_VECTOR)
     {
-    sprintf (string, "type=\"vector\"");
+    sprintf (string, "model=\"vector\"");
     gamgi_expat_export_attribute (fp, string, depth, column, error);
     }
 
@@ -1606,24 +1606,24 @@ if (fabs (euler[0] - 0.0) > GAMGI_MATH_TOLERANCE
  * volume (optional) *
  *********************/
 
-if (cell->type != GAMGI_PHYS_CONVENTIONAL)
+if (cell->model != GAMGI_PHYS_CONVENTIONAL)
   {
-  if (cell->type == GAMGI_PHYS_PRIMITIVE)
-    sprintf (string, "type=\"%s\"", "primitive");
-  else if (cell->type == GAMGI_PHYS_WIGNER)
-    sprintf (string, "type=\"%s\"", "wigner");
-  else if (cell->type == GAMGI_PHYS_PARALLELEPIPED)
-    sprintf (string, "type=\"%s\"", "parallelepiped");
-  else if (cell->type == GAMGI_PHYS_SPHERE)
-    sprintf (string, "type=\"%s\"", "sphere");
-  else if (cell->type == GAMGI_PHYS_PROJECTION)
-    sprintf (string, "type=\"%s\"", "projection");
+  if (cell->model == GAMGI_PHYS_PRIMITIVE)
+    sprintf (string, "model=\"%s\"", "primitive");
+  else if (cell->model == GAMGI_PHYS_WIGNER)
+    sprintf (string, "model=\"%s\"", "wigner");
+  else if (cell->model == GAMGI_PHYS_PARALLELEPIPED)
+    sprintf (string, "model=\"%s\"", "parallelepiped");
+  else if (cell->model == GAMGI_PHYS_SPHERE)
+    sprintf (string, "model=\"%s\"", "sphere");
+  else if (cell->model == GAMGI_PHYS_PROJECTION)
+    sprintf (string, "model=\"%s\"", "projection");
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
-if ((cell->type == GAMGI_PHYS_CONVENTIONAL
-|| cell->type == GAMGI_PHYS_PRIMITIVE
-|| cell->type == GAMGI_PHYS_WIGNER) &&
+if ((cell->model == GAMGI_PHYS_CONVENTIONAL
+|| cell->model == GAMGI_PHYS_PRIMITIVE
+|| cell->model == GAMGI_PHYS_WIGNER) &&
 (cell->n1 != 1 || cell->n2 != 1 || cell->n3 != 1))
   {
   /********************************
@@ -1638,8 +1638,8 @@ if ((cell->type == GAMGI_PHYS_CONVENTIONAL
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
-if (cell->type == GAMGI_PHYS_PARALLELEPIPED 
-|| cell->type == GAMGI_PHYS_SPHERE)
+if (cell->model == GAMGI_PHYS_PARALLELEPIPED 
+|| cell->model == GAMGI_PHYS_SPHERE)
   {
   /*****************
    * v1 (required) *
@@ -1649,7 +1649,7 @@ if (cell->type == GAMGI_PHYS_PARALLELEPIPED
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
-if (cell->type == GAMGI_PHYS_PARALLELEPIPED)
+if (cell->model == GAMGI_PHYS_PARALLELEPIPED)
   {
   /********************************
    * v2,v3,v12,v13,v23 (required) *
@@ -1671,7 +1671,7 @@ if (cell->type == GAMGI_PHYS_PARALLELEPIPED)
  * nodes,faces,borders (optional) *
  **********************************/
 
-if (cell->nodes == FALSE && cell->type != GAMGI_PHYS_PROJECTION)
+if (cell->nodes == FALSE && cell->model != GAMGI_PHYS_PROJECTION)
   gamgi_expat_export_attribute (fp, "nodes=\"no\"", depth, column, error);
 
 if (cell->faces == TRUE) 
@@ -1680,8 +1680,8 @@ if (cell->faces == TRUE)
 if (cell->borders == FALSE)
   gamgi_expat_export_attribute (fp, "borders=\"none\"", depth, column, error);
 
-if (cell->borders == GAMGI_PHYS_EDGES && cell->type != GAMGI_PHYS_PARALLELEPIPED
-&& cell->type != GAMGI_PHYS_SPHERE && cell->type != GAMGI_PHYS_PROJECTION)
+else if (cell->borders == GAMGI_PHYS_EDGES && cell->model != GAMGI_PHYS_PARALLELEPIPED
+&& cell->model != GAMGI_PHYS_SPHERE && cell->model != GAMGI_PHYS_PROJECTION)
   gamgi_expat_export_attribute (fp, "borders=\"edges\"", depth, column, error);
 
 else if (cell->borders == GAMGI_PHYS_FACES && cell->faces == FALSE)
