@@ -22,6 +22,7 @@
 #include "gamgi_gtk_history.h"
 #include "gamgi_gtk_object.h"
 #include "gamgi_mesa_select.h"
+#include "gamgi_mesa_draw.h"
 #include "gamgi_io_token.h"
 #include "gamgi_global_selection.h"
 
@@ -442,7 +443,7 @@ if (scope < 4)
  * For all windows: redraw gl_area image *
  *****************************************/
 
-gamgi_global_selection_draw ();
+gamgi_mesa_draw_gamgi ();
 }
 
 static void static_ok_local (int scope, gamgi_window *window)
