@@ -555,7 +555,7 @@ char token[GAMGI_ENGINE_TOKEN];
  **************************/
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_temperature");
-sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_TEMPERATURE, atom_class->temperature);
+sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_OCCUPANCY, atom_class->temperature);
 gtk_entry_set_text (GTK_ENTRY (entry), token);
 
 /************************************
