@@ -799,21 +799,16 @@ static void static_init (gamgi_window *window)
 GtkWidget *dialog = window->dialog0;
 GtkWidget *notebook;
 
-/****************
- * set notebook *
- ****************/
+/**********************************
+ * set notebook page and property *
+ **********************************/
 
 notebook = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "notebook");
-gtk_notebook_set_page (GTK_NOTEBOOK (notebook), 0);
-
-g_signal_connect (GTK_OBJECT (notebook), "switch_page",
-G_CALLBACK (static_switch), window);
-
-/****************
- * set property *
- ****************/
-
+gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), 0);
 static_switch (GTK_NOTEBOOK (notebook), NULL, 0, window);
+
+g_signal_connect (notebook, "switch_page",
+G_CALLBACK (static_switch), window);
 }
 
 static void static_press (gamgi_object *object, void *data)
@@ -863,7 +858,7 @@ if (entry == NULL) static_ok (NULL, window);
  *******************************************************/
 
 void gamgi_gtk_atom_measure_press (gamgi_window *window_mouse,
-int x, int y, gamgi_window *window_dialog)
+GdkEventButton *event, int x, int y, gamgi_window *window_dialog)
 {
 /******************************
  * local mouse selection only *
@@ -886,9 +881,8 @@ void gamgi_gtk_atom_measure (GtkWidget *widget, void *data)
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog;
 GtkWidget *notebook;
-GtkWidget *vbox_dialog, *vbox_page, *vbox_frame;
+GtkWidget *vbox_dialog, *vbox_page, *vbox_top;
 GtkWidget *hbox_center, *hbox_left;
-GtkWidget *frame;
 GtkWidget *entry;
 GtkWidget *button;
 GtkWidget *label;
@@ -920,7 +914,6 @@ gtk_widget_show (vbox_dialog);
 notebook = gtk_notebook_new ();
 gtk_box_pack_start (GTK_BOX (vbox_dialog), notebook, FALSE, FALSE, 0);
 gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), GTK_POS_TOP);
-gtk_notebook_set_homogeneous_tabs (GTK_NOTEBOOK (notebook), TRUE);
 g_object_set_data (G_OBJECT (dialog), "notebook", notebook);
 gtk_widget_show (notebook);
 
@@ -931,25 +924,19 @@ gtk_widget_show (notebook);
 label = gtk_label_new ("Length");
 vbox_page = gtk_vbox_new (FALSE, 0);
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (FALSE, 5);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_top = gtk_vbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top);
 
 /*****************
  * Property menu *
  *****************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
 hbox_left = gtk_hbox_new (FALSE, 5);
@@ -962,7 +949,7 @@ gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (combo), "changed",
+g_signal_connect (combo, "changed",
 G_CALLBACK (static_activate), window);
 g_object_set_data (G_OBJECT (vbox_page), "combo_property", combo);
 gtk_widget_show (combo);
@@ -990,7 +977,7 @@ gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NU
  ******************/
 
 hbox_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_left, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
 entry = gtk_entry_new ();
@@ -1009,7 +996,7 @@ gtk_widget_show (label);
  ************/
 
 hbox_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_left, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
 entry = gtk_entry_new ();
@@ -1029,7 +1016,7 @@ gtk_widget_show (label);
  ************/
 
 hbox_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_left, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
 entry = gtk_entry_new ();
@@ -1049,7 +1036,7 @@ gtk_widget_show (label);
  ************/
 
 hbox_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_left, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
 entry = gtk_entry_new ();
@@ -1069,7 +1056,7 @@ gtk_widget_show (label);
  *********/
 
 hbox_left = gtk_hbox_new (FALSE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_left, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
 entry = gtk_entry_new ();
@@ -1090,25 +1077,19 @@ gtk_widget_show (label);
 label = gtk_label_new ("Angle");
 vbox_page = gtk_vbox_new (FALSE, 0);
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (FALSE, 5);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_top = gtk_vbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top);
 
 /*****************
  * Property menu *
  *****************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
 hbox_left = gtk_hbox_new (FALSE, 5);
@@ -1121,7 +1102,7 @@ gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (combo), "changed",
+g_signal_connect (combo, "changed",
 G_CALLBACK (static_activate), window);
 g_object_set_data (G_OBJECT (vbox_page), "combo_property", combo);
 gtk_widget_show (combo);
@@ -1143,7 +1124,7 @@ gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NU
  *****************/
 
 hbox_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_left, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
 entry = gtk_entry_new ();
@@ -1162,7 +1143,7 @@ gtk_widget_show (label);
  ************/
 
 hbox_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_left, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
 entry = gtk_entry_new ();
@@ -1182,7 +1163,7 @@ gtk_widget_show (label);
  ************/
 
 hbox_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_left, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
 entry = gtk_entry_new ();
@@ -1202,7 +1183,7 @@ gtk_widget_show (label);
  ************/
 
 hbox_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_left, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
 entry = gtk_entry_new ();
@@ -1222,7 +1203,7 @@ gtk_widget_show (label);
  *********/
 
 hbox_left = gtk_hbox_new (FALSE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_left, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
 entry = gtk_entry_new ();
@@ -1246,18 +1227,16 @@ gtk_widget_show (hbox_center);
 
 button = gamgi_gtk_dialog_button_create ("Ok", NULL);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_ok), window);
 gtk_widget_show (button);
 
 button = gamgi_gtk_dialog_button_create ("Cancel", "red");
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_widget_grab_focus (button);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_dialog_task0_remove), window);
 gtk_widget_show (button);
 
