@@ -22,7 +22,7 @@
 #include "gamgi_gtk_history.h"
 #include "gamgi_gtk_object.h"
 #include "gamgi_mesa_select.h"
-#include "gamgi_chem_atom.h"
+#include "gamgi_mesa_draw.h"
 #include "gamgi_io_token.h"
 #include "gamgi_global_selection.h"
 
@@ -124,7 +124,7 @@ gamgi_dlist *dlist;
 
 if (scope == 0)
   {
-  gamgi_chem_atom_unlink (atom);
+  gamgi_engine_unlink_atom (atom);
   gamgi_engine_remove_atom (atom);
   }
 
@@ -137,7 +137,7 @@ else if (scope == 1)
   parent = atom->object.object;
   gamgi_engine_reparent_orbital (atom->orbital_start, parent);
   gamgi_engine_reparent_text (atom->text_start, parent);
-  gamgi_chem_atom_unlink (atom);
+  gamgi_engine_unlink_atom (atom);
   gamgi_engine_remove_atom (atom);
   }
 
@@ -260,7 +260,7 @@ if (scope < 2)
  * For all windows: redraw gl_area image *
  *****************************************/
 
-gamgi_global_selection_draw ();
+gamgi_mesa_draw_gamgi ();
 }
 
 static void static_ok_local (int scope, gamgi_window *window)
