@@ -177,7 +177,7 @@ entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_maximum");
 gtk_entry_set_text (GTK_ENTRY (entry), "");
 }
 
-static void static_method (GtkWidget *widget, void *data)
+static void static_model (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
@@ -408,16 +408,16 @@ gamgi_io_token_float_scan (name, &bond->blue, 0.0, 1.0) == FALSE)
   }
 
 /************************
- * determine the method *
+ * determine the model  *
  * used to create bonds *
  ************************/
 
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_atoms");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
   {
-  /***************
-   * pick method *
-   ***************/
+  /**************
+   * pick model *
+   **************/
 
   /**************
    * get atom 1 *
@@ -574,7 +574,7 @@ else
 
   /*******************************************
    * generate list with atoms in the current *
-   * object, for element and voronoi methods *
+   * object, for element and voronoi models  *
    *******************************************/
 
   atom_list = gamgi_engine_dlist_atom_object (window->focus, NULL);
@@ -688,7 +688,7 @@ gtk_entry_set_text (GTK_ENTRY (entry), token);
  * hide Length page *
  ********************/
 
-static_method (NULL, window);
+static_model (NULL, window);
 
 /************************************************************
  * initialize dependent parameters: size and red,green,blue *
@@ -848,12 +848,12 @@ gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), GTK_POS_TOP);
 g_object_set_data (G_OBJECT (dialog), "notebook", notebook);
 gtk_widget_show (notebook);
 
-/***************
- * method page *
- ***************/
+/*************
+ * Type page *
+ *************/
 
 vbox_page = gtk_vbox_new (FALSE, 5);
-label = gtk_label_new ("Method");
+label = gtk_label_new (" Type ");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
 gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
@@ -881,7 +881,7 @@ gtk_widget_show (hbox_left);
 button = gtk_radio_button_new_with_label (NULL, "Atoms");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
 g_signal_connect (button, "clicked",
-G_CALLBACK (static_method), window);
+G_CALLBACK (static_model), window);
 g_object_set_data (G_OBJECT (dialog), "button_atoms", button);
 gtk_widget_show (button);
 
@@ -889,7 +889,7 @@ button = gtk_radio_button_new_with_label (
 gtk_radio_button_get_group (GTK_RADIO_BUTTON (button)), "Length");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
 g_signal_connect (button, "clicked",
-G_CALLBACK (static_method), window);
+G_CALLBACK (static_model), window);
 g_object_set_data (G_OBJECT (dialog), "button_length", button);
 gtk_widget_show (button);
 
@@ -897,7 +897,7 @@ button = gtk_radio_button_new_with_label (
 gtk_radio_button_get_group (GTK_RADIO_BUTTON (button)), "Delaunay");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
 g_signal_connect (button, "clicked",
-G_CALLBACK (static_method), window);
+G_CALLBACK (static_model), window);
 g_object_set_data (G_OBJECT (dialog), "button_voronoi", button);
 gtk_widget_show (button);
 
