@@ -21,7 +21,7 @@ static void static_limit (GtkWidget *widget, void *data);
 
 static void static_length (gamgi_window *window);
 
-static void static_method (GtkWidget *widget, void *data);
+static void static_model (GtkWidget *widget, void *data);
 
 static void static_reset (gamgi_window *window);
 
