@@ -103,7 +103,7 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)) == TRUE)
 else sensitive[GAMGI_PHYS_ALL - 1] = TRUE;
 }
 
-static void static_type (GtkWidget *widget, void *data)
+static void static_model (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
@@ -118,10 +118,10 @@ GtkWidget *combo;
 char token[GAMGI_ENGINE_TOKEN];
 const char *name;
 gamgi_bool *sensitive;
-int row_type, row_borders;
+int row_model, row_borders;
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_type");
-row_type = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_model");
+row_model = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 /*******************************************
  * set N1, N2, N3 entries and Faces button *
@@ -137,8 +137,8 @@ label_n3 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_n3");
 
 button_faces = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_faces");
 
-if (row_type != GAMGI_PHYS_PARALLELEPIPED - 1 && 
-row_type != GAMGI_PHYS_SPHERE - 1 && row_type != GAMGI_PHYS_PROJECTION - 1)
+if (row_model != GAMGI_PHYS_PARALLELEPIPED - 1 && 
+row_model != GAMGI_PHYS_SPHERE - 1 && row_model != GAMGI_PHYS_PROJECTION - 1)
   {
   /******************
    * enable widgets *
@@ -217,8 +217,8 @@ label_v12 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_v12");
 label_v13 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_v13");
 label_v23 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_v23");
 
-if (row_type == GAMGI_PHYS_PARALLELEPIPED - 1 || 
-row_type == GAMGI_PHYS_SPHERE - 1)
+if (row_model == GAMGI_PHYS_PARALLELEPIPED - 1 || 
+row_model == GAMGI_PHYS_SPHERE - 1)
   {
   /******************
    * enable widgets *
@@ -238,7 +238,7 @@ else
   gtk_widget_set_sensitive (label_v1, FALSE);
   }
 
-if (row_type == GAMGI_PHYS_PARALLELEPIPED - 1)
+if (row_model == GAMGI_PHYS_PARALLELEPIPED - 1)
   {
   /******************
    * enable widgets *
@@ -291,8 +291,8 @@ row_borders = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 button_nodes = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_nodes");
 
-if (row_type != GAMGI_PHYS_PARALLELEPIPED - 1 &&
-row_type != GAMGI_PHYS_SPHERE - 1 && row_type != GAMGI_PHYS_PROJECTION - 1)
+if (row_model != GAMGI_PHYS_PARALLELEPIPED - 1 &&
+row_model != GAMGI_PHYS_SPHERE - 1 && row_model != GAMGI_PHYS_PROJECTION - 1)
   {
   /****************************
    * enable Borders combo box *
@@ -314,7 +314,7 @@ else
   sensitive[GAMGI_PHYS_FACES - 1] = FALSE;
   }
 
-if (row_type != GAMGI_PHYS_PROJECTION - 1)
+if (row_model != GAMGI_PHYS_PROJECTION - 1)
   {
   /***********************
    * enable Nodes button *
@@ -637,16 +637,16 @@ gamgi_io_token_double_scan (name, &euler[2], 0.0, 360.0) == FALSE)
   return;
   }
 
-/*****************
- * get Type page *
- *****************/
+/*******************
+ * get Volume page *
+ *******************/
 
-/********
- * Type *
- ********/
+/*********
+ * Model *
+ *********/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_type");
-cell->type = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_model");
+cell->model = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 /**************
  * N1, N2, N3 *
@@ -756,7 +756,7 @@ if (gtk_widget_is_sensitive (entry) == TRUE && gamgi_io_token_double_scan (name,
  * two, or smaller than the difference of the other two  *
  *********************************************************/
 
-if (cell->type == GAMGI_PHYS_PARALLELEPIPED)
+if (cell->model == GAMGI_PHYS_PARALLELEPIPED)
   {
   if (cell->v12 + cell->v13 + cell->v23 > 360.0 - GAMGI_MATH_TOLERANCE_ANGLE)
     {
@@ -945,7 +945,7 @@ if (cell->faces == FALSE && cell->nodes == FALSE && cell->borders == FALSE)
   return;
   }
 
-if (cell->type == GAMGI_PHYS_WIGNER && (cell->lattice == GAMGI_PHYS_TRICLINIC_P ||
+if (cell->model == GAMGI_PHYS_WIGNER && (cell->lattice == GAMGI_PHYS_TRICLINIC_P ||
 cell->lattice == GAMGI_PHYS_MONOCLINIC_P || cell->lattice == GAMGI_PHYS_MONOCLINIC_C) )
   {
   gamgi_gtk_dialog_message_create ("Error", "Sorry, not supported yet", window);
@@ -997,9 +997,9 @@ char token[GAMGI_ENGINE_TOKEN];
  * Borders, Faces, Nodes in the View page are also modified *
  ************************************************************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_type");
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_model");
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_PHYS_CONVENTIONAL - 1);
-static_type (NULL, window);
+static_model (NULL, window);
 
 /***********************
  * start Position page *
@@ -1247,9 +1247,9 @@ vbox_top = gtk_vbox_new (FALSE, 10);
 gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
-/******************
- * Type combo box *
- ******************/
+/*******************
+ * Model combo box *
+ *******************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
@@ -1259,14 +1259,14 @@ hbox_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
-label = gtk_label_new ("Type");
+label = gtk_label_new ("Model");
 gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
-g_signal_connect (combo, "changed", G_CALLBACK (static_type), window);
-g_object_set_data (G_OBJECT (dialog), "combo_type", combo);
+g_signal_connect (combo, "changed", G_CALLBACK (static_model), window);
+g_object_set_data (G_OBJECT (dialog), "combo_model", combo);
 gtk_widget_show (combo);
 
 store = gtk_list_store_new (1, G_TYPE_STRING);
