@@ -26,7 +26,7 @@ static void static_press (gamgi_object *object, void *data);
  **********************/
 
 void gamgi_gtk_cell_measure_press (gamgi_window *window_mouse,
-int x, int y, gamgi_window *window_dialog);
+GdkEventButton *event, int x, int y, gamgi_window *window_dialog);
 
 void gamgi_gtk_cell_measure (GtkWidget *widget, void *data);
 
