@@ -305,7 +305,7 @@ g_object_unref (store);
 gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (combo), 0);
 }
 
-static void static_method_type (char *label, gamgi_window *window)
+static void static_method_model (char *label, gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
 GtkWidget *widget;
@@ -391,40 +391,6 @@ gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NU
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
 }
 
-static void static_method_axes (char *label, gamgi_window *window)
-{
-GtkWidget *dialog = window->dialog0;
-GtkWidget *widget;
-GtkWidget *hbox;
-GtkWidget *combo;
-GtkListStore *store;
-GtkCellRenderer *renderer;
-GtkTreeIter iter;
-
-widget = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), label);
-hbox = gtk_widget_get_parent (widget);
-gtk_widget_destroy (widget);
-
-combo = gtk_combo_box_new ();
-gtk_box_pack_start (GTK_BOX (hbox), combo, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), label, combo);
-gtk_widget_show (combo);
-
-store = gtk_list_store_new (1, G_TYPE_STRING);
-gtk_list_store_append (store, &iter);
-gtk_list_store_set (store, &iter, 0, " Yes ", -1);
-gtk_list_store_append (store, &iter);
-gtk_list_store_set (store, &iter, 0, " No ", -1);
-gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
-g_object_unref (store);
-
-renderer = gtk_cell_renderer_text_new ();
-gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
-gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
-
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
-}
-
 static void static_method_borders (char *label, gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
@@ -463,74 +429,6 @@ gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NU
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
 }
 
-static void static_method_faces (char *label, gamgi_window *window)
-{
-GtkWidget *dialog = window->dialog0;
-GtkWidget *widget;
-GtkWidget *hbox;
-GtkWidget *combo;
-GtkListStore *store;
-GtkCellRenderer *renderer;
-GtkTreeIter iter;
-
-widget = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), label);
-hbox = gtk_widget_get_parent (widget);
-gtk_widget_destroy (widget);
-
-combo = gtk_combo_box_new ();
-gtk_box_pack_start (GTK_BOX (hbox), combo, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), label, combo);
-gtk_widget_show (combo);
-
-store = gtk_list_store_new (1, G_TYPE_STRING);
-gtk_list_store_append (store, &iter);
-gtk_list_store_set (store, &iter, 0, " Yes ", -1);
-gtk_list_store_append (store, &iter);
-gtk_list_store_set (store, &iter, 0, " No ", -1);
-gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
-g_object_unref (store);
-
-renderer = gtk_cell_renderer_text_new ();
-gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
-gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
-
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
-}
-
-static void static_method_nodes (char *label, gamgi_window *window)
-{
-GtkWidget *dialog = window->dialog0;
-GtkWidget *widget;
-GtkWidget *hbox;
-GtkWidget *combo;
-GtkListStore *store;
-GtkCellRenderer *renderer;
-GtkTreeIter iter;
-
-widget = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), label);
-hbox = gtk_widget_get_parent (widget);
-gtk_widget_destroy (widget);
-
-combo = gtk_combo_box_new ();
-gtk_box_pack_start (GTK_BOX (hbox), combo, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), label, combo);
-gtk_widget_show (combo);
-
-store = gtk_list_store_new (1, G_TYPE_STRING);
-gtk_list_store_append (store, &iter);
-gtk_list_store_set (store, &iter, 0, " Yes ", -1);
-gtk_list_store_append (store, &iter);
-gtk_list_store_set (store, &iter, 0, " No ", -1);
-gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
-g_object_unref (store);
-
-renderer = gtk_cell_renderer_text_new ();
-gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
-gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
-
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
-}
-
 static void static_method (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
@@ -569,6 +467,12 @@ if (strcmp (name, "Pick") == 0 || strcmp (name, "Region") == 0)
   gamgi_gtk_select_method_direct ("widget_min", window);
   gamgi_gtk_select_method_direct ("widget_max", window);
   }
+else if (strcmp (name, "Faces") == 0 || strcmp (name,
+"Nodes") == 0 || strcmp (name, "Axes") == 0)
+  {
+  gamgi_gtk_select_method_bool ("widget_min", window);
+  gamgi_gtk_select_method_bool ("widget_max", window);
+  }
 else if (strcmp (name, "System") == 0)
   {
   static_method_system ("widget_min", window);
@@ -579,36 +483,21 @@ else if (strcmp (name, "Lattice") == 0)
   static_method_lattice ("widget_min", window);
   static_method_lattice ("widget_max", window);
   }
-else if (strcmp (name, "Type") == 0)
+else if (strcmp (name, "Model") == 0)
   {
-  static_method_type ("widget_min", window);
-  static_method_type ("widget_max", window);
+  static_method_model ("widget_min", window);
+  static_method_model ("widget_max", window);
   }
 else if (strcmp (name, "O4") == 0)
   {
   static_method_o4 ("widget_min", window);
   static_method_o4 ("widget_max", window);
   }
-else if (strcmp (name, "Axes") == 0)
-  {
-  static_method_axes ("widget_min", window);
-  static_method_axes ("widget_max", window);
-  }
 else if (strcmp (name, "Borders") == 0)
   {
   static_method_borders ("widget_min", window);
   static_method_borders ("widget_max", window);
   }
-else if (strcmp (name, "Faces") == 0)
-  {
-  static_method_faces ("widget_min", window);
-  static_method_faces ("widget_max", window);
-  }
-else if (strcmp (name, "Nodes") == 0)
-  {
-  static_method_nodes ("widget_min", window);
-  static_method_nodes ("widget_max", window);
-  }
 else
   {
   gamgi_gtk_select_method_default ("widget_min", window);
@@ -1131,13 +1020,13 @@ for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
 return dlist_new;
 }
 
-static gamgi_dlist *static_ok_type (gamgi_dlist *dlist_old,
+static gamgi_dlist *static_ok_model (gamgi_dlist *dlist_old,
 gamgi_bool action, gamgi_window *window)
 {
 gamgi_cell *cell;
 gamgi_dlist *dlist, *dlist_new;
 gamgi_bool condition;
-gamgi_enum type;
+gamgi_enum model;
 int min, max;
 
 /********************
@@ -1154,8 +1043,8 @@ dlist_new = NULL;
 for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
   {
   cell = GAMGI_CAST_CELL dlist->data;
-  type = cell->type - 1;
-  condition = (type >= min && type <= max);
+  model = cell->model - 1;
+  condition = (model >= min && model <= max);
 
   if (condition != action)
     {
@@ -2223,8 +2112,8 @@ else if (strcmp (name, "AC") == 0)
 else if (strcmp (name, "AB") == 0)
   dlist_new = static_ok_ab (dlist_old, action, window);
 
-else if (strcmp (name, "Type") == 0)
-  dlist_new = static_ok_type (dlist_old, action, window);
+else if (strcmp (name, "Model") == 0)
+  dlist_new = static_ok_model (dlist_old, action, window);
 else if (strcmp (name, "N1") == 0)
   dlist_new = static_ok_n1 (dlist_old, action, window);
 else if (strcmp (name, "N2") == 0)
@@ -2445,7 +2334,6 @@ GtkWidget *frame;
 GtkWidget *treeview;
 GtkWidget *combo;
 GtkWidget *button;
-GtkWidget *entry;
 GtkWidget *label;
 GtkWidget *hbox_center, *hbox_left;
 GtkWidget *vbox_dialog, *vbox_page, *vbox_top, *vbox_top_top;
@@ -2687,7 +2575,7 @@ gtk_tree_store_set (tree_store, &child, 0, "AB", -1);
 gtk_tree_store_append (tree_store, &iter, NULL);
 gtk_tree_store_set (tree_store, &iter, 0, "Volume", -1);
 gtk_tree_store_append (tree_store, &child, &iter);
-gtk_tree_store_set (tree_store, &child, 0, "Type", -1);
+gtk_tree_store_set (tree_store, &child, 0, "Model", -1);
 gtk_tree_store_append (tree_store, &child, &iter);
 gtk_tree_store_set (tree_store, &child, 0, "N1", -1);
 gtk_tree_store_append (tree_store, &child, &iter);
@@ -2787,12 +2675,13 @@ hbox_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
-entry = gtk_entry_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left), entry, FALSE, FALSE, 0);
-gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_10);
-gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_10);
-g_object_set_data (G_OBJECT (dialog), "widget_min", entry);
-gtk_widget_show (entry);
+/**********************************************
+ * this widget will be removed in static_init *
+ **********************************************/
+
+combo = gtk_combo_box_new ();
+gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "widget_min", combo);
 
 /*******
  * Max *
@@ -2810,12 +2699,13 @@ hbox_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
-entry = gtk_entry_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left), entry, FALSE, FALSE, 0);
-gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_10);
-gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_10);
-g_object_set_data (G_OBJECT (dialog), "widget_max", entry);
-gtk_widget_show (entry);
+/**********************************************
+ * this widget will be removed in static_init *
+ **********************************************/
+
+combo = gtk_combo_box_new ();
+gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "widget_max", combo);
 
 /*********************
  * Ok/Cancel buttons *
