@@ -1700,21 +1700,21 @@ int *sensitive = (int *) g_object_get_data (G_OBJECT (dialog), "sensitive_o4");
 
 if (lattice == 0)
   {
-  sensitive[GAMGI_PHYS_NODE_011] = TRUE;
-  sensitive[GAMGI_PHYS_NODE_101] = TRUE;
-  sensitive[GAMGI_PHYS_NODE_110] = TRUE;
-  sensitive[GAMGI_PHYS_NODE_111] = TRUE;
-  sensitive[GAMGI_PHYS_NODE_211] = TRUE;
-  sensitive[GAMGI_PHYS_NODE_122] = TRUE;
+  sensitive[GAMGI_PHYS_011] = TRUE;
+  sensitive[GAMGI_PHYS_101] = TRUE;
+  sensitive[GAMGI_PHYS_110] = TRUE;
+  sensitive[GAMGI_PHYS_111] = TRUE;
+  sensitive[GAMGI_PHYS_211] = TRUE;
+  sensitive[GAMGI_PHYS_122] = TRUE;
   return;
   }
 
-sensitive[GAMGI_PHYS_NODE_011] = FALSE;
-sensitive[GAMGI_PHYS_NODE_101] = FALSE;
-sensitive[GAMGI_PHYS_NODE_110] = FALSE;
-sensitive[GAMGI_PHYS_NODE_111] = FALSE;
-sensitive[GAMGI_PHYS_NODE_211] = FALSE;
-sensitive[GAMGI_PHYS_NODE_122] = FALSE;
+sensitive[GAMGI_PHYS_011] = FALSE;
+sensitive[GAMGI_PHYS_101] = FALSE;
+sensitive[GAMGI_PHYS_110] = FALSE;
+sensitive[GAMGI_PHYS_111] = FALSE;
+sensitive[GAMGI_PHYS_211] = FALSE;
+sensitive[GAMGI_PHYS_122] = FALSE;
 
 if (lattice == -1 || vectors == GAMGI_PHYS_PRIMITIVE) return;
 
@@ -1723,24 +1723,24 @@ switch (lattice)
   case GAMGI_PHYS_CUBIC_I:
   case GAMGI_PHYS_TETRAGONAL_I:
   case GAMGI_PHYS_ORTHORHOMBIC_I:
-  sensitive[GAMGI_PHYS_NODE_111] = TRUE;
+  sensitive[GAMGI_PHYS_111] = TRUE;
   break;
 
   case GAMGI_PHYS_CUBIC_F:
   case GAMGI_PHYS_ORTHORHOMBIC_F:
-  sensitive[GAMGI_PHYS_NODE_011] = TRUE;
-  sensitive[GAMGI_PHYS_NODE_101] = TRUE;
-  sensitive[GAMGI_PHYS_NODE_110] = TRUE;
+  sensitive[GAMGI_PHYS_011] = TRUE;
+  sensitive[GAMGI_PHYS_101] = TRUE;
+  sensitive[GAMGI_PHYS_110] = TRUE;
   break;
 
   case GAMGI_PHYS_ORTHORHOMBIC_C:
   case GAMGI_PHYS_MONOCLINIC_C:
-  sensitive[GAMGI_PHYS_NODE_110] = TRUE;
+  sensitive[GAMGI_PHYS_110] = TRUE;
   break;
 
   case GAMGI_PHYS_HEXAGONAL_R:
-  sensitive[GAMGI_PHYS_NODE_211] = TRUE;
-  sensitive[GAMGI_PHYS_NODE_122] = TRUE;
+  sensitive[GAMGI_PHYS_211] = TRUE;
+  sensitive[GAMGI_PHYS_122] = TRUE;
   break;
 
   default:
