@@ -426,7 +426,7 @@ static gamgi_bool static_apply (gamgi_object *child, gamgi_object *parent,
 gamgi_layer *layer_child, gamgi_layer *layer_parent, gamgi_window *window)
 {
 if (child->class == GAMGI_ENGINE_DIRECTION &&
-(GAMGI_CAST_DIRECTION child)->type != GAMGI_PHYS_LINE)
+(GAMGI_CAST_DIRECTION child)->model != GAMGI_PHYS_LINE)
   {
   if (cache.local == TRUE)
     gamgi_gtk_dialog_message_create ("Error",
