@@ -771,7 +771,7 @@ static void static_direction (gamgi_direction *direction,
 gamgi_cell *cell, gamgi_enum structure, gamgi_enum filter,
 double thickness, gamgi_dlist *dlist, gamgi_enum pole, gamgi_enum trace)
 {
-if (cell->type == GAMGI_PHYS_PROJECTION)
+if (cell->model == GAMGI_PHYS_PROJECTION)
   gamgi_phys_direction_projection (direction, cell, pole, trace);
 else
   gamgi_phys_direction_node (direction,
