@@ -83,7 +83,7 @@ switch (page)
 switch (page)
   {
   case 0:
-  if (quantity == 2 && gamgi_io_token_check (name) == FALSE)
+  if (quantity == 3 && gamgi_io_token_check (name) == FALSE)
     return GAMGI_ENGINE_ATOM;
   break;
 
@@ -125,7 +125,7 @@ switch (page)
 switch (page)
   {
   case 0:
-  if (quantity == 2 && gamgi_io_token_check (name) == FALSE)
+  if (quantity == 3 && gamgi_io_token_check (name) == FALSE)
     return entry;
   break;
  
@@ -267,12 +267,12 @@ switch (page)
   case 0:
   switch (quantity)
     {
-    case 0: case 1:
+    case 0: case 1: case 2:
     gtk_entry_set_text (GTK_ENTRY (entry1), "");
     gtk_label_set_text (GTK_LABEL (label1), "Object");
     break;
 
-    case 2:
+    case 3:
     gtk_label_set_text (GTK_LABEL (label1), "Atom");
     break;
     }
@@ -301,12 +301,12 @@ switch (page)
   case 0:
   switch (quantity)
     {
-    case 0: case 1:
+    case 0: case 1: case 2:
     gtk_widget_set_sensitive (entry1, FALSE);
     gtk_widget_set_sensitive (label1, FALSE);
     break;
 
-    case 2:
+    case 3:
     gtk_widget_set_sensitive (entry1, TRUE);
     gtk_widget_set_sensitive (label1, TRUE);
     break;
@@ -409,7 +409,7 @@ switch (page)
   case 0:
   switch (quantity)
     {
-    case 2:
+    case 3:
     atom1 = static_atom (vbox, "entry_object1", window);
     if (atom1 == NULL) return;
     }
@@ -460,7 +460,16 @@ switch (page)
     break;
 
     case 1:
-    if (gamgi_math_measure_length_direction (direction0, &length) == FALSE)
+    if (gamgi_math_measure_length_node_direction (direction0, &length) == FALSE)
+      {
+      gamgi_gtk_dialog_message_create ("Error", "Invalid Geometry Data", window);
+      return;
+      }
+    sprintf (token, "%.*f", gamgi->gamgi->length, length);
+    break;
+
+    case 2:
+    if (gamgi_math_measure_length_node_direction (direction0, &length) == FALSE)
       {
       gamgi_gtk_dialog_message_create ("Error", "Invalid Geometry Data", window);
       return;
@@ -468,7 +477,7 @@ switch (page)
     sprintf (token, "%.*f", gamgi->gamgi->length, 1.0/length);
     break;
 
-    case 2:
+    case 3:
     if (gamgi_math_measure_length_atom_direction (atom1,
     direction0, &length) == FALSE)
       {
@@ -678,6 +687,8 @@ gtk_widget_show (combo);
 
 store = gtk_list_store_new (1, G_TYPE_STRING);
 gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Direction Length", -1);
+gtk_list_store_append (store, &iter);
 gtk_list_store_set (store, &iter, 0, "Direction Node Length", -1);
 gtk_list_store_append (store, &iter);
 gtk_list_store_set (store, &iter, 0, "Direction Node Density", -1);
