@@ -76,8 +76,8 @@ gamgi_enum vectors;
 gamgi_enum structure, filter;
 double thickness;
 int node[4];
-gamgi_projection projection;
-gamgi_enum type;
+gamgi_net net;
+gamgi_enum model;
 double translation[3], rotation[3];
 float red, green, blue;
 double scale; } cache;
@@ -604,7 +604,7 @@ cell = GAMGI_CAST_CELL gamgi_gtk_object_name_number (dialog,
 "entry_cell", GAMGI_ENGINE_CELL, window);
 if (cell != NULL)
   {
-  if (cell->type == GAMGI_PHYS_PROJECTION)
+  if (cell->model == GAMGI_PHYS_PROJECTION)
     {
     gtk_widget_hide (vbox_scope);
     gtk_widget_hide (vbox_position);
@@ -992,9 +992,9 @@ row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 if (visible == TRUE && row < STATIC_NET_LOCAL)
   {
   cache.new[STATIC_NET] = TRUE;
-  cache.projection = NULL;
-  if (row == STATIC_NET_WULFF) cache.projection = gamgi_phys_projection_wulff;
-  if (row == STATIC_NET_SCHMIDT) cache.projection = gamgi_phys_projection_schmidt;
+  cache.net = NULL;
+  if (row == STATIC_NET_WULFF) cache.net = gamgi_phys_projection_wulff;
+  if (row == STATIC_NET_SCHMIDT) cache.net = gamgi_phys_projection_schmidt;
   }
 
 cache.new[STATIC_MODEL] = FALSE;
@@ -1003,9 +1003,9 @@ row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 if (visible == TRUE && row < STATIC_MODEL_LOCAL)
   {
   cache.new[STATIC_MODEL] = TRUE;
-  cache.type = FALSE;
-  if (row == STATIC_MODEL_POLE) cache.type = GAMGI_PHYS_POLE;
-  if (row == STATIC_MODEL_TRACE) cache.type = GAMGI_PHYS_TRACE;
+  cache.model = FALSE;
+  if (row == STATIC_MODEL_POLE) cache.model = GAMGI_PHYS_POLE;
+  if (row == STATIC_MODEL_TRACE) cache.model = GAMGI_PHYS_TRACE;
   }
 
 /*********************************
@@ -1173,8 +1173,8 @@ gamgi_cell *cell;
 gamgi_object *parent;
 gamgi_dlist *dlist;
 char name[GAMGI_ENGINE_TOKEN];
-gamgi_projection projection;
-gamgi_enum reference, vectors, type;
+gamgi_net net;
+gamgi_enum reference, vectors, model;
 gamgi_bool link[2];
 gamgi_bool new;
 double zero[3], euler[3], origin[3];
@@ -1200,8 +1200,8 @@ uvw[1] = direction->uvw[1];
 uvw[2] = direction->uvw[2];
 vectors = direction->vectors;
 
-projection = direction->projection;
-type = direction->type;
+net = direction->net;
+model = direction->model;
 node[0] = direction->node[0];
 node[1] = direction->node[1];
 node[2] = direction->node[2];
@@ -1228,8 +1228,8 @@ if (cache.new[STATIC_V] == TRUE) uvw[1] = cache.uvw[1];
 if (cache.new[STATIC_W] == TRUE) uvw[2] = cache.uvw[2];
 if (cache.new[STATIC_VECTORS] == TRUE) vectors = cache.vectors;
 
-if (cache.new[STATIC_NET] == TRUE) projection = cache.projection;
-if (cache.new[STATIC_MODEL] == TRUE) type = cache.type;
+if (cache.new[STATIC_NET] == TRUE) net = cache.net;
+if (cache.new[STATIC_MODEL] == TRUE) model = cache.model;
 if (cache.new[STATIC_O1] == TRUE) node[0] = cache.node[0];
 if (cache.new[STATIC_O2] == TRUE) node[1] = cache.node[1];
 if (cache.new[STATIC_O3] == TRUE) node[2] = cache.node[2];
@@ -1260,16 +1260,16 @@ if (cache.new[STATIC_REFERENCE] == TRUE)
     uvw[0] = 0; uvw[1] = 0; uvw[2] = 0;
     vectors = GAMGI_PHYS_DIRECTION_VECTORS;
     node[0] = 0; node[1] = 0; node[2] = 0; node[3] = 0;
-    type = GAMGI_PHYS_LINE;
-    projection = NULL;
+    model = GAMGI_PHYS_LINE;
+    net = NULL;
     }
 
   if (reference == GAMGI_ENGINE_CELL)
     {
-    if (cell->type == GAMGI_PHYS_PROJECTION)
+    if (cell->model == GAMGI_PHYS_PROJECTION)
       { node[0] = 0; node[1] = 0; node[2] = 0; node[3] = 0; }
     else
-      { type = GAMGI_PHYS_LINE; projection = NULL; }
+      { model = GAMGI_PHYS_LINE; net = NULL; }
     }
   }
 
@@ -1287,8 +1287,8 @@ if (reference == GAMGI_ENGINE_CELL)
     return FALSE;
     }
 
-  if ((type == GAMGI_PHYS_POLE || type == GAMGI_PHYS_TRACE) &&
-  (projection == NULL || cell == NULL || cell->type != GAMGI_PHYS_PROJECTION))
+  if ((model == GAMGI_PHYS_POLE || model == GAMGI_PHYS_TRACE) &&
+  (net == NULL || cell == NULL || cell->model != GAMGI_PHYS_PROJECTION))
     {
     if (cache.local == TRUE)
       gamgi_gtk_dialog_message_create ("Error",
@@ -1296,7 +1296,7 @@ if (reference == GAMGI_ENGINE_CELL)
     return FALSE;
     }
 
-  if (type != GAMGI_PHYS_POLE && type != GAMGI_PHYS_TRACE && projection != NULL)
+  if (model != GAMGI_PHYS_POLE && model != GAMGI_PHYS_TRACE && net != NULL)
     {
     if (cache.local == TRUE)
       gamgi_gtk_dialog_message_create ("Error",
@@ -1331,7 +1331,7 @@ if (reference == GAMGI_ENGINE_ATOM)
     return FALSE;
     }
 
-  if (projection != NULL)
+  if (net != NULL)
     {
     if (cache.local == TRUE)
       gamgi_gtk_dialog_message_create ("Error",
@@ -1339,7 +1339,7 @@ if (reference == GAMGI_ENGINE_ATOM)
     return FALSE;
     }
 
-  if (type == GAMGI_PHYS_POLE || type == GAMGI_PHYS_TRACE)
+  if (model == GAMGI_PHYS_POLE || model == GAMGI_PHYS_TRACE)
     {
     if (cache.local == TRUE)
       gamgi_gtk_dialog_message_create ("Error",
@@ -1408,10 +1408,10 @@ if (direction->node[0] != node[0]) new = TRUE;
 if (direction->node[1] != node[1]) new = TRUE;
 if (direction->node[2] != node[2]) new = TRUE;
 if (direction->node[3] != node[3]) new = TRUE;
-if (direction->projection != projection) new = TRUE;
-if (direction->type != type) new = TRUE;
+if (direction->net != net) new = TRUE;
+if (direction->model != model) new = TRUE;
 
-if (new == TRUE && type == GAMGI_PHYS_LINE &&
+if (new == TRUE && model == GAMGI_PHYS_LINE &&
 cache.new[STATIC_THICKNESS] == FALSE)
   {
   if (cache.local == TRUE)
@@ -1443,8 +1443,8 @@ direction->node[0] = node[0];
 direction->node[1] = node[1];
 direction->node[2] = node[2];
 direction->node[3] = node[3];
-direction->projection = projection;
-direction->type = type;
+direction->net = net;
+direction->model = model;
 
 direction->red = red;
 direction->green = green;
@@ -1486,10 +1486,10 @@ if (new == TRUE)
      * this is a crystallographic direction *
      ****************************************/
 
-    if (cell->type == GAMGI_PHYS_PROJECTION)
+    if (cell->model == GAMGI_PHYS_PROJECTION)
       {
-      if (direction->type == GAMGI_PHYS_POLE) pole = TRUE; else pole = FALSE;
-      if (direction->type == GAMGI_PHYS_TRACE) trace = TRUE; else trace = FALSE;
+      if (direction->model == GAMGI_PHYS_POLE) pole = TRUE; else pole = FALSE;
+      if (direction->model == GAMGI_PHYS_TRACE) trace = TRUE; else trace = FALSE;
       gamgi_phys_direction_projection (direction, cell, pole, trace);
       }
     else
@@ -1515,7 +1515,7 @@ if (new == TRUE)
      * the direction type is needed because of the rotation next *
      *************************************************************/
 
-    direction->type = GAMGI_PHYS_LINE;
+    direction->model = GAMGI_PHYS_LINE;
     direction->vectors = GAMGI_PHYS_DIRECTION_VECTORS;
 
     parent = gamgi_phys_direction_parent (cache.atom1, cache.atom2, window);
@@ -1779,18 +1779,18 @@ if (class == GAMGI_ENGINE_DIRECTION)
     combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_vectors");
     gtk_combo_box_set_active (GTK_COMBO_BOX (combo), direction->vectors - 1);
 
-    if (cell->type == GAMGI_PHYS_PROJECTION)
+    if (cell->model == GAMGI_PHYS_PROJECTION)
       {
       combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_model");
-      if (direction->type == GAMGI_PHYS_POLE)
+      if (direction->model == GAMGI_PHYS_POLE)
         gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_MODEL_POLE);
-      if (direction->type == GAMGI_PHYS_TRACE)
+      if (direction->model == GAMGI_PHYS_TRACE)
         gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_MODEL_TRACE);
 
       combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_net");
-      if (direction->projection == gamgi_phys_projection_wulff)
+      if (direction->net == gamgi_phys_projection_wulff)
         gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_NET_WULFF);
-      if (direction->projection == gamgi_phys_projection_schmidt)
+      if (direction->net == gamgi_phys_projection_schmidt)
         gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_NET_SCHMIDT);
       }
     else
