@@ -222,7 +222,7 @@ if (gamgi_phys_direction_weiss (uvw, range.hkl1) == FALSE)
 range.start1 = -INT_MAX;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_start1");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE &&
+if (gtk_widget_is_sensitive (entry) == TRUE &&
 gamgi_io_token_int_scan (name, &range.start1, -INT_MAX, INT_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid first plane order", window);
@@ -231,7 +231,7 @@ gamgi_io_token_int_scan (name, &range.start1, -INT_MAX, INT_MAX) == FALSE)
 range.end1 = INT_MAX;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_end1");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE &&
+if (gtk_widget_is_sensitive (entry) == TRUE &&
 gamgi_io_token_int_scan (name, &range.end1, -INT_MAX, INT_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid first plane order", window);
@@ -308,7 +308,7 @@ if (gamgi_phys_direction_weiss (uvw, range.hkl2) == FALSE)
 range.start2 = -INT_MAX;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_start2");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE && 
+if (gtk_widget_is_sensitive (entry) == TRUE && 
 gamgi_io_token_int_scan (name, &range.start2, -INT_MAX, INT_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid second plane order", window);
@@ -318,7 +318,7 @@ gamgi_io_token_int_scan (name, &range.start2, -INT_MAX, INT_MAX) == FALSE)
 range.end2 = INT_MAX;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_end2");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (GTK_WIDGET_SENSITIVE (entry) == TRUE &&
+if (gtk_widget_is_sensitive (entry) == TRUE &&
 gamgi_io_token_int_scan (name, &range.end2, -INT_MAX, INT_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid second plane order", window);
