@@ -22,6 +22,7 @@
 #include "gamgi_gtk_history.h"
 #include "gamgi_gtk_object.h"
 #include "gamgi_mesa_select.h"
+#include "gamgi_mesa_draw.h"
 #include "gamgi_chem_atom.h"
 #include "gamgi_io_token.h"
 #include "gamgi_global_selection.h"
@@ -153,13 +154,11 @@ if (scope == 2)
   {
   dlist = direction->atom_start;
   while (dlist != NULL)
-    {
-    atom = GAMGI_CAST_ATOM dlist->data;
-    dlist = dlist->next;
-    gamgi_chem_atom_unlink (atom);
-    gamgi_engine_remove_atom (atom);
-    }
-
+    { gamgi_engine_remove_atom (GAMGI_CAST_ATOM dlist->data);
+      dlist = gamgi_engine_dlist_remove_start (dlist); }
+   direction->atom_start = NULL;
+   direction->atom_end = NULL;
+ 
   dlist = direction->orbital_start;
   while (dlist != NULL)
     { gamgi_engine_remove_orbital (GAMGI_CAST_ORBITAL dlist->data);
@@ -184,12 +183,10 @@ if (scope == 3)
   {
   dlist = direction->atom_start;
   while (dlist != NULL)
-    {
-    atom = GAMGI_CAST_ATOM dlist->data;
-    dlist = dlist->next;
-    gamgi_chem_atom_unlink (atom);
-    gamgi_engine_remove_atom (atom);
-    }
+    { gamgi_engine_remove_atom (GAMGI_CAST_ATOM dlist->data);
+      dlist = gamgi_engine_dlist_remove_start (dlist); }
+  direction->atom_start = NULL;
+  direction->atom_end = NULL;
   }
 
 /****************************************************
@@ -289,7 +286,7 @@ if (scope < 2)
  * For all windows: redraw gl_area image *
  *****************************************/
 
-gamgi_global_selection_draw ();
+gamgi_mesa_draw_gamgi ();
 }
 
 static void static_ok_local (int scope, gamgi_window *window)
