@@ -189,14 +189,18 @@ gamgi_dlist *dlist;
  * remove global dialogs *
  *************************/
 
-gamgi_gtk_dialog_remove (gamgi->question, &gamgi->question);
-if (gamgi->message != NULL)
-  gamgi_gtk_dialog_remove (gamgi->message, &gamgi->message);
+gamgi_gtk_dialog_global_remove ();
 
-/**********************************************************
- * remove all windows except current: dialogs may address *
- * other windows, so it is important to remove them first *
- **********************************************************/
+/*********************************
+ * remove object selection lists *
+ *********************************/
+
+gamgi_global_selection_remove_all ();
+
+/*******************************************************************
+ * remove dialogs, timers, windows except current: dialogs may     *
+ * address other windows, so it is important to remove them first! *
+ *******************************************************************/
 
 for (window = gamgi->window_start; window != NULL; window = window->next)
   gamgi_gtk_window_remove_dialogs (window);
