@@ -532,7 +532,7 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
    * lattice is useful only for centered lattices *
    ************************************************/
 
-  if (cell->type != GAMGI_PHYS_CONVENTIONAL ||
+  if (cell->model != GAMGI_PHYS_CONVENTIONAL ||
   gamgi_phys_cell_primitive (cell->lattice) == cell->lattice)
     {
     gamgi_gtk_dialog_message_create ("Error", 
