@@ -27,6 +27,7 @@
 #include "gamgi_chem_atom.h"
 #include "gamgi_chem_bond.h"
 #include "gamgi_io_token.h"
+#include "gamgi_global_selection.h"
 
 gamgi_object *static_address (gamgi_enum class, 
 gamgi_window *window, long number)
@@ -207,39 +208,6 @@ GAMGI_ENGINE_TOKEN, 1, LONG_MAX) == FALSE) return NULL;
 return static_address (class, window, number);
 }
 
-gamgi_bool gamgi_gtk_object_independence (gamgi_object *object)
-{
-gamgi_plane *plane;
-gamgi_direction *direction;
-
-/******************************************************************************
- * Crystallographic planes and directions are not truely independent objects, *
- * because they depend of their cell parents. Atomic planes and directions    *
- * are defined by atoms that must belong to them, so they are independent     *
- * of their parents and can be freely linked, even to different layers.       *
- ******************************************************************************/
-   
-switch (object->class)
-  {
-  case GAMGI_ENGINE_PLANE:
-  plane = GAMGI_CAST_PLANE object;
-  if (plane->reference == GAMGI_ENGINE_CELL) return FALSE;
-  if (plane->autonomy == GAMGI_GTK_NONE) return FALSE;
-  break;
-
-  case GAMGI_ENGINE_DIRECTION:
-  direction = GAMGI_CAST_DIRECTION object;
-  if (direction->reference == GAMGI_ENGINE_CELL) return FALSE;
-  if (direction->autonomy == GAMGI_GTK_NONE) return FALSE;
-  break;
-
-  default:
-  break;
-  }
-
-return TRUE;
-}
-
 gamgi_bool gamgi_gtk_object_name (GtkWidget *host,
 char *tag, char *label, char *name)
 {
@@ -307,21 +275,23 @@ window->layer = layer;
 gamgi_gtk_statusbar_layer_show (window);
 }
 
-void gamgi_gtk_object_focus_local (gamgi_object *object, gamgi_window *window)
+void gamgi_gtk_object_focus_local (gamgi_object *object,
+gamgi_window *window_dialog)
 {
-gamgi_window *window_now;
+gamgi_window *window;
 
 /***********************************************************
- * if the current object is gamgi, the first window in the *
-   list must know, because it existed before (the current  *
-   window might be a new window), unless this is the first *
-   window created, in which case the focus cannot be gamgi *
+ * if the current object is Gamgi, the first window in the *
+ * list must know, because it existed before (the current  *
+ * window might be a new window), unless this is the first *
+ * window created, in which case the focus cannot be Gamgi *
  ***********************************************************/
 
-if (gamgi->window_start->focus == GAMGI_CAST_OBJECT gamgi->gamgi)
+if (gamgi->focus != FALSE)
   {
-  for (window_now = gamgi->window_start; 
-  window_now != NULL; window_now = window_now->next)
+  gamgi->focus = FALSE;
+  for (window = gamgi->window_start; 
+  window != NULL; window = window->next)
     {
     /****************************************************************
      * the test for NULL is needed because when importing windows   *
@@ -329,28 +299,32 @@ if (gamgi->window_start->focus == GAMGI_CAST_OBJECT gamgi->gamgi)
      * not gtk-created, so window exists but window->window not yet *
      ****************************************************************/
 
-    if (window_now != window && window_now->window != NULL)
+    if (window != window_dialog && window->window != NULL)
       {
-      window_now->focus = GAMGI_CAST_OBJECT window_now->layer;
-      gamgi_gtk_statusbar_focus_show (window_now);
+      window->focus = GAMGI_CAST_OBJECT window->layer;
+      gamgi_gtk_statusbar_focus_show (window);
       }
     }
   }
 
-window->focus = object;
-gamgi_gtk_statusbar_focus_show (window);
+window_dialog->focus = object;
+gamgi_gtk_statusbar_focus_show (window_dialog);
 }
 
-void gamgi_gtk_object_focus_global (void)
+void gamgi_gtk_object_focus_global (gamgi_window *window_dialog)
 {
 gamgi_window *window;
 
-for (window = gamgi->window_start; window != NULL; window = window->next)
+if (gamgi_global_selection_list (window_dialog->class) == NULL)
   {
-  window->focus = GAMGI_CAST_OBJECT gamgi->gamgi;
-  gamgi_gtk_statusbar_focus_show (window);
+  gamgi_gtk_dialog_message_create ("Error",
+  "Empty list of selected objects", window_dialog);
+  return;
   }
 
+gamgi->focus = window_dialog->class;
+for (window = gamgi->window_start; window != NULL; window = window->next)
+  gamgi_gtk_statusbar_focus_show (window);
 }
 
 gamgi_layer *gamgi_gtk_object_layer_create (gamgi_window *window)
@@ -459,22 +433,6 @@ gamgi_engine_find_object (parent, child) == TRUE)
   gamgi_engine_link_object_object (parent, child->object);
   }
   
-/*******************************************************************
- * some objects, such as planes and directions, might depend       *
- * entirely on their parents (crystallographic planes,directions), *
- * or have a life of their own (atomic planes,directions). Only    *
- * the second can be linked to other parents (not necessarily in   *
- * the same layer). Dependent objects can be linked, however,      *
- * to all possible child objects, without any restrictions.        *
- *******************************************************************/
-
-if (gamgi_gtk_object_independence (child) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", 
-  "Child is not an independent object", window);
-  return;
-  }
-
 /**********************************
  * get current linking situation  *
  * before linking child to parent *
@@ -535,16 +493,7 @@ else
     window_child->layer, window_child);
   }
 
-/********************************************************
- * link child to parent: if atom is defining an         *
- * atomic plane,direction then reparent plane,direction *
- * child objects and remove plane,direction             *
- ********************************************************/
-
-if (child->class == GAMGI_ENGINE_ATOM)
-  gamgi_chem_atom_unlink (GAMGI_CAST_ATOM child);
-else
-  gamgi_engine_unlink_object (child);
+gamgi_engine_unlink_object (child);
 gamgi_engine_link_object_object (child, parent);
 
 /********************************************************
