@@ -589,10 +589,9 @@ gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO)
 
 text = gamgi_gtk_dialog_text_create ();
 
-/********************************************************
- * apply Polytope algorithm: independent is the minimum *
- * number of independent atom positions that were found *
- ********************************************************/
+/****************************
+ * apply Polytope algorithm *
+ ****************************/
 
 if (gamgi_chem_polytope (dlist, group, atom, global, structure,
 visible, coplanar, element, number, radius, out, text) == FALSE)
@@ -615,34 +614,19 @@ else
   if (global == FALSE) gamgi_engine_remove_group (group);
   }
 
-if (out[GAMGI_MATH_POLYTOPE_1] == 1)
+if (out[GAMGI_MATH_POLYTOPE_1] > 0)
   {
-  sprintf (string, "Ignored one Group, ");
+  sprintf (string, "Ignored Groups (%d), ", out[GAMGI_MATH_POLYTOPE_1]);
   strcat (line, string);
   }
-else if (out[GAMGI_MATH_POLYTOPE_1] > 1)
+if (out[GAMGI_MATH_POLYTOPE_2] > 0)
   {
-  sprintf (string, "Ignored %d Groups, ", out[GAMGI_MATH_POLYTOPE_1]);
+  sprintf (string, "Created Directions (%d), ", out[GAMGI_MATH_POLYTOPE_2]);
   strcat (line, string);
   }
-if (out[GAMGI_MATH_POLYTOPE_2] == 1)
+if (out[GAMGI_MATH_POLYTOPE_3] > 0)
   {
-  sprintf (string, "Created one Direction, ");
-  strcat (line, string);
-  }
-else if (out[GAMGI_MATH_POLYTOPE_2] > 1)
-  {
-  sprintf (string, "Created %d Directions, ", out[GAMGI_MATH_POLYTOPE_2]);
-  strcat (line, string);
-  }
-if (out[GAMGI_MATH_POLYTOPE_3] == 1)
-  {
-  sprintf (string, "Created one Plane, ");
-  strcat (line, string);
-  }
-else if (out[GAMGI_MATH_POLYTOPE_3] > 1)
-  {
-  sprintf (string, "Created %d Planes, ", out[GAMGI_MATH_POLYTOPE_3]);
+  sprintf (string, "Created Planes (%d), ", out[GAMGI_MATH_POLYTOPE_3]);
   strcat (line, string);
   }
 if (line[0] != '\0') strcat (line, "due to improper atom coordinates");
