@@ -111,7 +111,8 @@ switch (window->action)
 
   case GAMGI_GTK_ORBITAL_MODIFY:
   gamgi_gtk_help_dialog_import ("Help Orbital Modify",  
-  "interfaces/orbital/modify", window, 0, n);
+  "interfaces/orbital/modify", window, 5, n,
+  "type", "model", "volume", "position", "view");
   break;
 
   case GAMGI_GTK_ORBITAL_REMOVE:
@@ -121,7 +122,7 @@ switch (window->action)
 
   case GAMGI_GTK_BOND_CREATE:
   gamgi_gtk_help_dialog_import ("Help Bond Create",  
-  "interfaces/bond/create", window, 4, n, "method", "length", 
+  "interfaces/bond/create", window, 4, n, "type", "length", 
   "property", "view");
   break;
 
