@@ -787,7 +787,7 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Bond",
 static void static_interfaces_bond_create (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Bond Create", 
-"interfaces/bond/create", data, 4, 1, "method", "length",
+"interfaces/bond/create", data, 4, 1, "type", "length",
 "property", "view");
 }
 
@@ -852,6 +852,13 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Orbital Link",
 "interfaces/orbital/link", data, 2, 1, "object", "shift");
 }
 
+static void static_interfaces_orbital_modify (void *data)
+{
+gamgi_gtk_help_dialog_import ("Help Interfaces Orbital Modify",
+"interfaces/orbital/modify", data, 5, 1,
+"type", "model", "volume", "position", "view");
+}
+
 static void static_interfaces_orbital_remove (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Orbital Remove",
@@ -1184,7 +1191,7 @@ gamgi_gtk_help_dialog_import ("Help Formats Cell",
 static void static_formats_cell_create (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Formats Cell Create",
-"formats/cell/create", data, 5, 1, "symmetry", "type", 
+"formats/cell/create", data, 5, 1, "symmetry", "volume", 
 "position", "origin", "view");
 }
 
@@ -1265,7 +1272,8 @@ gamgi_gtk_help_dialog_import ("Help Formats Atom",
 static void static_formats_atom_create (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Formats Atom Create",
-"formats/atom/create", data, 0, 0);
+"formats/atom/create", data, 5, 1, "type", "property",
+"analysis", "position", "view");
 }
 
 static void static_formats_atom_config (void *data)
@@ -1283,7 +1291,7 @@ gamgi_gtk_help_dialog_import ("Help Formats Bond",
 static void static_formats_bond_create (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Formats Bond Create",
-"formats/bond/create", data, 3, 1, "mode", "type", "view");
+"formats/bond/create", data, 3, 1, "type", "property", "view");
 }
 
 static void static_formats_bond_config (void *data)
@@ -1301,7 +1309,8 @@ gamgi_gtk_help_dialog_import ("Help Formats Orbital",
 static void static_formats_orbital_create (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Formats Orbital Create",
-"formats/orbital/create", data, 1, 1, "view");
+"formats/orbital/create", data, 5, 1, "type", "model",
+"volume", "position", "view");
 }
 
 static void static_formats_text (void *data)
@@ -1551,6 +1560,7 @@ static_row (store, &iter2, "Create", static_interfaces_orbital_create);
 static_row (store, &iter2, "Copy", static_interfaces_orbital_copy);
 static_row (store, &iter2, "Select", static_interfaces_orbital_select);
 static_row (store, &iter2, "Link", static_interfaces_orbital_link);
+static_row (store, &iter2, "Modify", static_interfaces_orbital_modify);
 static_row (store, &iter2, "Remove", static_interfaces_orbital_remove);
 
 iter2 = static_row (store, &iter1, "Text", static_interfaces_text);
