@@ -11,7 +11,6 @@
 
 #include "gamgi_engine.h"
 #include "gamgi_gtk.h"
-#include "gamgi_mesa.h"
 #include "gamgi_io.h"
 #include "gamgi_global.h"
 
@@ -91,7 +90,7 @@ entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_layer");
 gtk_entry_set_text (GTK_ENTRY (entry), string);
 }
 
-static void static_location (GtkWidget *widget, void *data)
+static void static_destination (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
@@ -100,7 +99,7 @@ GtkWidget *combo;
 int row;
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_window");
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_location");
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_destination");
 row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 if (row == STATIC_WINDOW)
   {
@@ -142,7 +141,7 @@ entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_number");
 sprintf (string, "%d", GAMGI_GTK_COPY_NUMBER);
 gtk_entry_set_text (GTK_ENTRY (entry), string);
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_location");
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_destination");
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_WINDOW);
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_x");
@@ -175,8 +174,8 @@ gamgi_bool *sensitive;
 
 hbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "hbox_layer");
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_location");
-sensitive = (gamgi_bool *) g_object_get_data (G_OBJECT (dialog), "sensitive_location");
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_destination");
+sensitive = (gamgi_bool *) g_object_get_data (G_OBJECT (dialog), "sensitive_destination");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
   {
   /*****************************
@@ -244,7 +243,7 @@ if (gamgi_io_token_int_scan (name, &cache.number, 1, INT_MAX) == FALSE)
  **********/
 
 cache.window = NULL;
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_location");
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_destination");
 row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 if (row == STATIC_WINDOW)
   {
@@ -252,7 +251,7 @@ if (row == STATIC_WINDOW)
   "entry_window", GAMGI_ENGINE_WINDOW, NULL);
   if (cache.window == NULL)
     {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid copy location", window);
+    gamgi_gtk_dialog_message_create ("Error", "Invalid copy destination", window);
     return FALSE;
     }
   }
@@ -522,15 +521,15 @@ gamgi_bool global;
 const char *name;
 int row;
 
-/***********************************************
- * local location is active only in List mode, *
- * so objects and locations are already known  *
- *                                             *
- * global selection can be used only to select *
- * the location, the object to copy is local   *
- ***********************************************/
+/**************************************************
+ * local destination is active only in List mode, *
+ * so objects and locations are already known     *
+ *                                                *
+ * global selection can be used only to select    *
+ * the destination, the object to copy is local   *
+ **************************************************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_location");
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_destination");
 row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 if (row == STATIC_LOCAL) return;
 
@@ -711,9 +710,9 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 g_object_set_data (G_OBJECT (dialog), "entry_number", entry);
 gtk_widget_show (entry);
 
-/************
- * Location *
- ************/
+/***************
+ * Destination *
+ ***************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
@@ -723,15 +722,15 @@ hbox_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
-label = gtk_label_new ("Location");
+label = gtk_label_new ("Destination");
 gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 5);
 gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
 g_signal_connect (combo, "changed",
-G_CALLBACK (static_location), window);
-g_object_set_data (G_OBJECT (dialog), "combo_location", combo);
+G_CALLBACK (static_destination), window);
+g_object_set_data (G_OBJECT (dialog), "combo_destination", combo);
 gtk_widget_show (combo);
 
 store = gtk_list_store_new (1, G_TYPE_STRING);
@@ -747,7 +746,7 @@ gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
 gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
 
 sensitive = gamgi_gtk_dialog_sensitive_create (2);
-g_object_set_data (G_OBJECT (dialog), "sensitive_location", sensitive);
+g_object_set_data (G_OBJECT (dialog), "sensitive_destination", sensitive);
 gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (combo),
 renderer, gamgi_gtk_dialog_sensitive_scan, sensitive, free);
 
