@@ -25,6 +25,7 @@
 #include "gamgi_gtk_history.h"
 #include "gamgi_mesa_select.h"
 #include "gamgi_mesa_translate.h"
+#include "gamgi_mesa_draw.h"
 #include "gamgi_math_vector.h"
 #include "gamgi_chem_atom.h"
 #include "gamgi_chem_bond.h"
@@ -106,21 +107,9 @@ static void static_reference (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
-GtkWidget *button, *button_list, *button_below;
-
-button_list = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
-button_below = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_below");
-
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button_list)) == TRUE
-&& gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button_below)) == TRUE)
-  {
-  button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_parent");
-  }
-else
-  {
-  button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_child");
-  }
+GtkWidget *button;
 
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_child");
 gtk_button_clicked (GTK_BUTTON (button));
 }
 
@@ -460,23 +449,6 @@ if (child->object == parent)
   return FALSE;
   }
 
-/*******************************************************************
- * some objects, such as planes and directions, might depend       *
- * entirely on their parents (crystallographic planes,directions), *
- * or have a life of their own (atomic planes,directions). Only    *
- * the second can be linked to other parents (not necessarily in   *
- * the same layer). Dependent objects can be linked, however,      *
- * to all possible child objects, without any restrictions.        *
- *******************************************************************/
-
-if (gamgi_gtk_object_independence (child) == FALSE)
-  {
-  if (cache.local == TRUE)
-    gamgi_gtk_dialog_message_create ("Error",
-    "Child is not an independent object", window_dialog);
-  return FALSE;
-  }
-
 if (cache.above == TRUE)
   {
   /****************************************
@@ -530,16 +502,7 @@ if (cache.above == FALSE)
     if (layer_child != layer_parent)
       gamgi_chem_bond_half_remove (child);
 
-    /********************************************************
-     * link child to parent: if atom is defining an         *
-     * atomic plane,direction then reparent plane,direction *
-     * child objects and remove plane,direction             *
-     ********************************************************/
-
-    if (child->class == GAMGI_ENGINE_ATOM)
-      gamgi_chem_atom_unlink (GAMGI_CAST_ATOM child);
-    else
-      gamgi_engine_unlink_object (child);
+    gamgi_engine_unlink_object (child);
     }
   else
     {
@@ -651,7 +614,7 @@ gamgi_io_error_list (start, window_dialog);
 
 gamgi_global_selection_layer ();
 gamgi_global_selection_focus ();
-gamgi_global_selection_draw ();
+gamgi_mesa_draw_gamgi ();
 
 /****************
  * reset dialog *
@@ -844,6 +807,7 @@ GdkEventButton *event, int x, int y, gamgi_window *window_dialog)
 GtkWidget *dialog = window_dialog->dialog0;
 GtkWidget *button;
 GtkWidget *entry;
+gamgi_bool global;
 const char *name;
 
 /***********************************************
@@ -859,13 +823,24 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE &&
 gamgi_io_token_check (name) == FALSE && 
 window_dialog != window_mouse) return;
 
+/***********************************************
+ * global selection can be used only to select *
+ * the second object, not the main object      *
+ ***********************************************/
+
+global = TRUE;
+if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE &&
+gamgi_io_token_check (name) == FALSE) global = FALSE;
+
 /************************************************************************
  * window_dialog is the (local) window where the dialog window was open *
  * window_mouse is the (global) window where the user presses the mouse *
  ************************************************************************/
 
+if (global == FALSE && window_dialog != window_mouse) return;
+
 gamgi_mesa_select_object (window_mouse, x, y, 
-static_class (window_dialog), TRUE, static_press);
+static_class (window_dialog), global, static_press);
 }
 
 /***************** external function ***************
