@@ -29,59 +29,6 @@
 #include "gamgi_math_position.h"
 #include "gamgi_io_token.h"
 
-static void static_axes (GtkWidget *widget, void *data)
-{
-gamgi_window *window = GAMGI_CAST_WINDOW data;
-GtkWidget *dialog = window->dialog0;
-GtkWidget *combo;
-GtkWidget *entry;
-GtkWidget *label;
-GtkWidget *button;
-char token[GAMGI_ENGINE_TOKEN] = "";
-const char *name;
-double radius;
-int axes;
-gamgi_bool active;
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_radius");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_frame");
-active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
-
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_axes");
-axes = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_length");
-label = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_length");
-
-if (axes == GAMGI_CHEM_AXES_NONE - 1)
-  {
-  gtk_widget_set_sensitive (entry, FALSE);
-  gtk_widget_set_sensitive (label, FALSE);
-  }
-else
-  {
-  gtk_widget_set_sensitive (entry, TRUE);
-  gtk_widget_set_sensitive (label, TRUE);
-
-  if (axes == GAMGI_CHEM_AXES_UNIT - 1)
-    sprintf (token, "%.*f", gamgi->gamgi->length, 1.0);
-
-  if (axes == GAMGI_CHEM_AXES_BOHR - 1)
-    sprintf (token, "%.*f", gamgi->gamgi->length, GAMGI_CHEM_A0);
-
-  if (axes == GAMGI_CHEM_AXES_FRAME - 1 && gamgi_io_token_double_scan (name,
-  &radius, GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == TRUE)
-    {
-    if (active == TRUE) radius *= 2.0;
-    sprintf (token, "%.*f", gamgi->gamgi->length, radius);
-    }
-  }
-
-gtk_entry_set_text (GTK_ENTRY (entry), token);
-}
-
 static void static_phase (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
@@ -186,7 +133,6 @@ else
   gtk_widget_set_sensitive (entry_green, FALSE);
   gtk_widget_set_sensitive (entry_blue, FALSE);
   }
-
 }
 
 static void static_style (GtkWidget *widget, void *data)
@@ -264,12 +210,6 @@ if (radius > 0.0)
   gtk_entry_set_text (GTK_ENTRY (entry), token);
   }
 else gtk_entry_set_text (GTK_ENTRY (entry), "");
-
-/***************************
- * set default axes length *
- ***************************/
-
-static_axes (NULL, window);
 }
 
 static void static_l (GtkWidget *widget, void *data)
@@ -424,6 +364,16 @@ if (gamgi_io_token_double_scan (name, &orbital->density, 0.0, 1.0) == FALSE)
   return;
   }
 
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_radius");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_double_scan (name, &orbital->radius,
+GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
+  {
+  gamgi_gtk_dialog_message_create ("Error", "Invalid sampling radius", window);
+  gamgi_engine_remove_orbital (orbital);
+  return;
+  }
+
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_sampling");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_int_scan (name, &orbital->sampling, 1, INT_MAX) == FALSE)
@@ -441,16 +391,6 @@ orbital->sampling > GAMGI_CHEM_ORBITAL_SLICES_MAX)
   return;
   }
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_radius");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_double_scan (name, &orbital->radius,
-GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid sampling radius", window);
-  gamgi_engine_remove_orbital (orbital);
-  return;
-  }
-
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_seed");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_int_scan (name, &orbital->seed, 1, INT_MAX) == FALSE)
@@ -460,9 +400,17 @@ if (gamgi_io_token_int_scan (name, &orbital->seed, 1, INT_MAX) == FALSE)
   return;
   }
 
-/**********************************
- * Volume page: get octants, axes *
- **********************************/
+/************************************************
+ * Volume page: get phase, frame, octants, axes *
+ ************************************************/
+
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_phase");
+if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+  orbital->phase = TRUE;
+
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_frame");
+if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+  orbital->frame = TRUE;
 
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_1");
 orbital->octants[0] = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
@@ -482,16 +430,7 @@ button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_8");
 orbital->octants[7] = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button));
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_axes");
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_length");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gtk_combo_box_get_active (GTK_COMBO_BOX (combo)) != GAMGI_CHEM_AXES_NONE - 1
-&& gamgi_io_token_double_scan (name, &orbital->axes, GAMGI_MATH_TOLERANCE_LENGTH,
-DBL_MAX) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid axes length", window);
-  gamgi_engine_remove_orbital (orbital);
-  return;
-  }
+orbital->axes = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 /*************************
  * get x,y,z coordinates *
@@ -558,9 +497,9 @@ if (gamgi_io_token_double_scan (name, &euler[2], 0.0, 360.0) == FALSE)
   return;
   }
 
-/************************************************************************
- * View page: get 1) Base, Phase, Frame colors; 2) Phase, Frame buttons *
- ************************************************************************/
+/********************************************
+ * View page: get Base, Phase, Frame colors *
+ ********************************************/
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_base_red");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
@@ -589,11 +528,8 @@ if (gamgi_io_token_float_scan (name, &orbital->base_b, 0.0, 1.0) == FALSE)
   return;
   }
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_phase");
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+if (orbital->phase == TRUE)
   {
-  orbital->phase = TRUE;
-
   entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_phase_red");
   name = gtk_entry_get_text (GTK_ENTRY (entry));
   if (gamgi_io_token_float_scan (name, &orbital->phase_r, 0.0, 1.0) == FALSE)
@@ -622,11 +558,8 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
     }
   }
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_frame");
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+if (orbital->frame == TRUE)
   {
-  orbital->frame = TRUE;
-
   entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_frame_red");
   name = gtk_entry_get_text (GTK_ENTRY (entry));
   if (gamgi_io_token_float_scan (name, &orbital->frame_r, 0.0, 1.0) == FALSE)
@@ -770,8 +703,7 @@ button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_8");
 gtk_button_clicked (GTK_BUTTON (button));
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_axes");
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_CHEM_AXES_NONE - 1);
-static_axes (NULL, window);
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), FALSE);
 
 /***********************
  * start Position page *
@@ -1194,9 +1126,9 @@ hbox_left = gtk_hbox_new (FALSE, 15);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
-/*******************
- * Density, Radius *
- *******************/
+/*********************
+ * Density, Sampling *
+ *********************/
 
 vbox_top_top = gtk_vbox_new (FALSE, 15);
 gtk_box_pack_start (GTK_BOX (hbox_left), vbox_top_top, FALSE, FALSE, 0);
@@ -1225,16 +1157,16 @@ entry = gtk_entry_new ();
 gtk_box_pack_end (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
-g_object_set_data (G_OBJECT (dialog), "entry_radius", entry);
+g_object_set_data (G_OBJECT (dialog), "entry_sampling", entry);
 gtk_widget_show (entry);
 
-label = gtk_label_new ("Radius");
+label = gtk_label_new ("Sampling");
 gtk_box_pack_end (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
-/******************
- * Sampling, Seed *
- ******************/
+/****************
+ * Radius, Seed *
+ ****************/
 
 vbox_top_top = gtk_vbox_new (FALSE, 15);
 gtk_box_pack_start (GTK_BOX (hbox_left), vbox_top_top, FALSE, FALSE, 0);
@@ -1248,10 +1180,10 @@ entry = gtk_entry_new ();
 gtk_box_pack_end (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
-g_object_set_data (G_OBJECT (dialog), "entry_sampling", entry);
+g_object_set_data (G_OBJECT (dialog), "entry_radius", entry);
 gtk_widget_show (entry);
 
-label = gtk_label_new ("Sampling");
+label = gtk_label_new ("Radius");
 gtk_box_pack_end (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
@@ -1390,7 +1322,6 @@ gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
-g_signal_connect (combo, "changed", G_CALLBACK (static_axes), window);
 g_object_set_data (G_OBJECT (dialog), "combo_axes", combo);
 gtk_widget_show (combo);
 
@@ -1410,18 +1341,6 @@ renderer = gtk_cell_renderer_text_new ();
 gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
 gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
 
-entry = gtk_entry_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left), entry, FALSE, FALSE, 0);
-gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
-gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
-g_object_set_data (G_OBJECT (dialog), "entry_length", entry);
-gtk_widget_show (entry);
-
-label = gtk_label_new ("Length");
-gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), "label_length", label);
-gtk_widget_show (label);
-
 /*****************
  * Position page *
  *****************/
