@@ -102,57 +102,6 @@ else
 gtk_entry_set_text (GTK_ENTRY (entry), string);
 }
 
-static void static_axes (GtkWidget *widget, void *data)
-{
-gamgi_window *window = GAMGI_CAST_WINDOW data;
-GtkWidget *dialog = window->dialog0;
-GtkWidget *combo;
-GtkWidget *entry;
-GtkWidget *label;
-char token[GAMGI_ENGINE_TOKEN] = "";
-const char *name;
-double radius;
-int axes, frame;
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_radius");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_frame");
-frame = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_axes");
-axes = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_axes");
-label = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_axes");
-
-if (axes == STATIC_AXES_NONE || axes == STATIC_AXES_LOCAL)
-  {
-  gtk_widget_set_sensitive (entry, FALSE);
-  gtk_widget_set_sensitive (label, FALSE);
-  }
-else
-  {
-  gtk_widget_set_sensitive (entry, TRUE);
-  gtk_widget_set_sensitive (label, TRUE);
-
-  if (axes == STATIC_AXES_UNIT)
-    sprintf (token, "%.*f", gamgi->gamgi->length, 1.0);
-
-  if (axes == STATIC_AXES_BOHR)
-    sprintf (token, "%.*f", gamgi->gamgi->length, GAMGI_CHEM_A0);
-
-  if (axes == STATIC_AXES_RADIUS && gamgi_io_token_double_scan (name,
-  &radius, GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == TRUE)
-    {
-    if (frame == STATIC_FRAME_YES) radius *= 2.0;
-    sprintf (token, "%.*f", gamgi->gamgi->length, radius);
-    }
-  }
-
-gtk_entry_set_text (GTK_ENTRY (entry), token);
-}
-
 static void static_phase (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
@@ -369,12 +318,12 @@ entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_seed");
 sprintf (token, "%d", GAMGI_MATH_SEED);
 gtk_entry_set_text (GTK_ENTRY (entry), token);
 
-/***************************
- * set default axes length *
- ***************************/
+/********************
+ * set default axes *
+ ********************/
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_axes");
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_AXES_NONE);
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), FALSE);
 }
 
 static void static_l (GtkWidget *widget, void *data)
@@ -586,13 +535,12 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
   }
 else
   {
-  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_axes");
-
   static_type_clean (window);
   static_model_clean (window);
-  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_AXES_LOCAL);
   gtk_widget_set_sensitive (hbox, FALSE);
   static_name (window, NULL);
+  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_axes");
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_AXES_LOCAL);
   }
 }
 
@@ -887,7 +835,7 @@ if (gamgi_io_token_check (name) == TRUE)
 cache.new[STATIC_PHASE] = FALSE;
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_phase");
 row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-if (row < 2)
+if (row < STATIC_PHASE_LOCAL)
   {
   cache.new[STATIC_PHASE] = TRUE;
   if (row == STATIC_PHASE_YES) cache.phase = TRUE;
@@ -897,7 +845,7 @@ if (row < 2)
 cache.new[STATIC_FRAME] = FALSE;
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_frame");
 row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-if (row < 2)
+if (row < STATIC_FRAME_LOCAL)
   {
   cache.new[STATIC_FRAME] = TRUE;
   if (row == STATIC_FRAME_YES) cache.frame = TRUE;
@@ -930,18 +878,10 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
 cache.new[STATIC_AXES] = FALSE;
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_axes");
 row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-if (row < 4)
+if (row < STATIC_AXES_LOCAL)
   {
   cache.new[STATIC_AXES] = TRUE;
-  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_axes");
-  name = gtk_entry_get_text (GTK_ENTRY (entry));
-  cache.axes = 0.0;
-  if (row > 0 && gamgi_io_token_double_scan (name,
-  &cache.axes, GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid orbital axes", window);
-    return FALSE;
-    }
+  cache.axes = row;
   }
 
 /******************************
@@ -1671,27 +1611,12 @@ gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), orbital->octants[6]);
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_8");
 gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), orbital->octants[7]);
 
-/********
- * axes *
- ********/
+/************
+ * set axes *
+ ************/
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_axes");
-if (orbital->axes == 0.0)
-  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_AXES_NONE);
-else if (orbital->axes == 1.0)
-  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_AXES_UNIT);
-else if (orbital->axes == GAMGI_CHEM_A0)
-  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_AXES_BOHR);
-else
-  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_AXES_RADIUS);
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_axes");
-if (orbital->axes == 0.0) gtk_entry_set_text (GTK_ENTRY (entry), "");
-else
-  {
-  sprintf (string, "%.*f", gamgi->gamgi->length, orbital->axes);
-  gtk_entry_set_text (GTK_ENTRY (entry), string);
-  }
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), orbital->axes);
 
 /*********************
  * set position data *
@@ -2158,9 +2083,9 @@ hbox_left = gtk_hbox_new (FALSE, 15);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
-/*******************
- * Density, Radius *
- *******************/
+/*********************
+ * Density, Sampling *
+ *********************/
 
 vbox_top_top = gtk_vbox_new (FALSE, 15);
 gtk_box_pack_start (GTK_BOX (hbox_left), vbox_top_top, FALSE, FALSE, 0);
@@ -2189,16 +2114,16 @@ entry = gtk_entry_new ();
 gtk_box_pack_end (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
-g_object_set_data (G_OBJECT (dialog), "entry_radius", entry);
+g_object_set_data (G_OBJECT (dialog), "entry_sampling", entry);
 gtk_widget_show (entry);
 
-label = gtk_label_new ("Radius");
+label = gtk_label_new ("Sampling");
 gtk_box_pack_end (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
-/******************
- * Sampling, Seed *
- ******************/
+/****************
+ * Radius, Seed *
+ ****************/
 
 vbox_top_top = gtk_vbox_new (FALSE, 15);
 gtk_box_pack_start (GTK_BOX (hbox_left), vbox_top_top, FALSE, FALSE, 0);
@@ -2212,10 +2137,10 @@ entry = gtk_entry_new ();
 gtk_box_pack_end (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
-g_object_set_data (G_OBJECT (dialog), "entry_sampling", entry);
+g_object_set_data (G_OBJECT (dialog), "entry_radius", entry);
 gtk_widget_show (entry);
 
-label = gtk_label_new ("Sampling");
+label = gtk_label_new ("Radius");
 gtk_box_pack_end (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
@@ -2409,7 +2334,6 @@ gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
-g_signal_connect (combo, "changed", G_CALLBACK (static_axes), window);
 g_object_set_data (G_OBJECT (dialog), "combo_axes", combo);
 gtk_widget_show (combo);
 
@@ -2431,18 +2355,6 @@ renderer = gtk_cell_renderer_text_new ();
 gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
 gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
 
-entry = gtk_entry_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left), entry, FALSE, FALSE, 0);
-gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
-gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
-g_object_set_data (G_OBJECT (dialog), "entry_axes", entry);
-gtk_widget_show (entry);
-
-label = gtk_label_new ("Length");
-gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), "label_axes", label);
-gtk_widget_show (label);
-
 /*****************
  * Position page *
  *****************/
