@@ -211,32 +211,54 @@ GtkWidget *dialog = window->dialog1;
 gamgi_cell *cell;
 GtkWidget *entry;
 GtkWidget *combo;
-char string[2 * GAMGI_ENGINE_TOKEN];
+char token[GAMGI_ENGINE_TOKEN];
 
 cell = GAMGI_CAST_CELL gamgi_gtk_object_name_number (window->dialog0,
 "entry_cell", GAMGI_ENGINE_CELL, window);
 static_nodes (cell, window);
 
-if (node.active == FALSE) return;
+if (node.active == FALSE)
+  {
+  /****************************
+   * show default coordinates *
+   ****************************/
 
-/*************************
- * show node coordinates *
- *************************/
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_o1");
+  sprintf (token, "%d", GAMGI_PHYS_NODE_O1);
+  gtk_entry_set_text (GTK_ENTRY (entry), token);
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_o1");
-sprintf (string, "%d", node.o1);
-gtk_entry_set_text (GTK_ENTRY (entry), string);
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_o2");
+  sprintf (token, "%d", GAMGI_PHYS_NODE_O2);
+  gtk_entry_set_text (GTK_ENTRY (entry), token);
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_o2");
-sprintf (string, "%d", node.o2);
-gtk_entry_set_text (GTK_ENTRY (entry), string);
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_o3");
+  sprintf (token, "%d", GAMGI_PHYS_NODE_O3);
+  gtk_entry_set_text (GTK_ENTRY (entry), token);
 
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_o3");
-sprintf (string, "%d", node.o3);
-gtk_entry_set_text (GTK_ENTRY (entry), string);
+  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_o4");
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), FALSE);
+  }
+else
+  {
+  /*************************
+   * show node coordinates *
+   *************************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_o4");
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), FALSE);
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_o1");
+  sprintf (token, "%d", node.o1);
+  gtk_entry_set_text (GTK_ENTRY (entry), token);
+
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_o2");
+  sprintf (token, "%d", node.o2);
+  gtk_entry_set_text (GTK_ENTRY (entry), token);
+
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_o3");
+  sprintf (token, "%d", node.o3);
+  gtk_entry_set_text (GTK_ENTRY (entry), token);
+
+  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_o4");
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), node.o4);
+  }
 }
 
 static void static_create (gamgi_window *window)
