@@ -12,6 +12,7 @@
 #include "gamgi_engine.h"
 #include "gamgi_gtk.h"
 #include "gamgi_mesa.h"
+#include "gamgi_phys.h"
 #include "gamgi_io.h"
 #include "gamgi_global.h"
 
@@ -21,6 +22,7 @@
 #include "gamgi_gtk_dialog.h"
 #include "gamgi_mesa_select.h"
 #include "gamgi_math_node.h"
+#include "gamgi_phys_projection.h"
 #include "gamgi_io_token.h"
 #include "gamgi_global_selection.h"
 
@@ -156,6 +158,78 @@ gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NU
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
 }
 
+static void static_method_model (char *label, gamgi_window *window)
+{
+GtkWidget *dialog = window->dialog0;
+GtkWidget *widget;
+GtkWidget *hbox;
+GtkWidget *combo;
+GtkListStore *store;
+GtkCellRenderer *renderer;
+GtkTreeIter iter;
+
+widget = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), label);
+hbox = gtk_widget_get_parent (widget);
+gtk_widget_destroy (widget);
+
+combo = gtk_combo_box_new ();
+gtk_box_pack_start (GTK_BOX (hbox), combo, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), label, combo);
+gtk_widget_show (combo);
+
+store = gtk_list_store_new (1, G_TYPE_STRING);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Polygon", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Pole", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Trace", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Vector", -1);
+gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
+g_object_unref (store);
+
+renderer = gtk_cell_renderer_text_new ();
+gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
+gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
+
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
+}
+
+static void static_method_net (char *label, gamgi_window *window)
+{
+GtkWidget *dialog = window->dialog0;
+GtkWidget *widget;
+GtkWidget *hbox;
+GtkWidget *combo;
+GtkListStore *store;
+GtkCellRenderer *renderer;
+GtkTreeIter iter;
+
+widget = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), label);
+hbox = gtk_widget_get_parent (widget);
+gtk_widget_destroy (widget);
+
+combo = gtk_combo_box_new ();
+gtk_box_pack_start (GTK_BOX (hbox), combo, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), label, combo);
+gtk_widget_show (combo);
+
+store = gtk_list_store_new (1, G_TYPE_STRING);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Wulff", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Schmidt", -1);
+gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
+g_object_unref (store);
+
+renderer = gtk_cell_renderer_text_new ();
+gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
+gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
+
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
+}
+
 static void static_method_o4 (char *label, gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
@@ -200,40 +274,6 @@ gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NU
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
 }
 
-static void static_method_style (char *label, gamgi_window *window)
-{
-GtkWidget *dialog = window->dialog0;
-GtkWidget *widget;
-GtkWidget *hbox;
-GtkWidget *combo;
-GtkListStore *store;
-GtkCellRenderer *renderer;
-GtkTreeIter iter;
-
-widget = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), label);
-hbox = gtk_widget_get_parent (widget);
-gtk_widget_destroy (widget);
-
-combo = gtk_combo_box_new ();
-gtk_box_pack_start (GTK_BOX (hbox), combo, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), label, combo);
-gtk_widget_show (combo);
-
-store = gtk_list_store_new (1, G_TYPE_STRING);
-gtk_list_store_append (store, &iter);
-gtk_list_store_set (store, &iter, 0, "Wired", -1);
-gtk_list_store_append (store, &iter);
-gtk_list_store_set (store, &iter, 0, "Solid", -1);
-gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
-g_object_unref (store);
-
-renderer = gtk_cell_renderer_text_new ();
-gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
-gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
-
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
-}
-
 static void static_method (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
@@ -277,16 +317,21 @@ else if (strcmp (name, "Reference") == 0)
   static_method_reference ("widget_min", window);
   static_method_reference ("widget_max", window);
   }
+else if (strcmp (name, "Model") == 0)
+  {
+  static_method_model ("widget_min", window);
+  static_method_model ("widget_max", window);
+  }
+else if (strcmp (name, "Net") == 0)
+  {
+  static_method_net ("widget_min", window);
+  static_method_net ("widget_max", window);
+  }
 else if (strcmp (name, "O4") == 0)
   {
   static_method_o4 ("widget_min", window);
   static_method_o4 ("widget_max", window);
   }
-else if (strcmp (name, "Style") == 0)
-  {
-  static_method_style ("widget_min", window);
-  static_method_style ("widget_max", window);
-  }
 else
   {
   gamgi_gtk_select_method_default ("widget_min", window);
@@ -474,6 +519,46 @@ for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
 return dlist_new;
 }
 
+static gamgi_dlist *static_ok_model (gamgi_dlist *dlist_old,
+gamgi_bool action, gamgi_window *window)
+{
+gamgi_plane *plane;
+gamgi_dlist *dlist, *dlist_new;
+gamgi_enum model;
+gamgi_bool condition;
+int min, max;
+
+/********************
+ * get range limits *
+ ********************/
+
+gamgi_gtk_select_combo_int (&min, &max, window);
+
+/******************************
+ * get list of selected planes *
+ ******************************/
+
+dlist_new = NULL;
+for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
+  {
+  plane = GAMGI_CAST_PLANE dlist->data;
+
+  if (plane->model == GAMGI_PHYS_POLYGON) model = 0;
+  if (plane->model == GAMGI_PHYS_POLE) model = 1;
+  if (plane->model == GAMGI_PHYS_TRACE) model = 2;
+  if (plane->model == GAMGI_PHYS_VECTOR) model = 3;
+  condition = (model >= min && model <= max);
+
+  if (condition != action)
+    {
+    dlist_new = gamgi_engine_dlist_add_start (dlist_new);
+    dlist_new->data = plane;
+    }
+  }
+
+return dlist_new;
+}
+
 static gamgi_dlist *static_ok_h (gamgi_dlist *dlist_old,
 gamgi_bool action, gamgi_window *window)
 {
@@ -582,6 +667,44 @@ for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
 return dlist_new;
 }
 
+static gamgi_dlist *static_ok_net (gamgi_dlist *dlist_old,
+gamgi_bool action, gamgi_window *window)
+{
+gamgi_plane *plane;
+gamgi_dlist *dlist, *dlist_new;
+gamgi_enum net;
+gamgi_bool condition;
+int min, max;
+
+/********************
+ * get range limits *
+ ********************/
+
+gamgi_gtk_select_combo_int (&min, &max, window);
+
+/******************************
+ * get list of selected planes *
+ ******************************/
+
+dlist_new = NULL;
+for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
+  {
+  plane = GAMGI_CAST_PLANE dlist->data;
+
+  if (plane->net == gamgi_phys_projection_wulff) net = 0;
+  if (plane->net == gamgi_phys_projection_schmidt) net = 1;
+  condition = (net >= min && net <= max);
+
+  if (condition != action)
+    {
+    dlist_new = gamgi_engine_dlist_add_start (dlist_new);
+    dlist_new->data = plane;
+    }
+  }
+
+return dlist_new;
+}
+
 static gamgi_dlist *static_ok_o1 (gamgi_dlist *dlist_old,
 gamgi_bool action, gamgi_window *window)
 {
@@ -953,6 +1076,8 @@ else if (strcmp (name, "Group") == 0)
 
 else if (strcmp (name, "Reference") == 0)
   dlist_new = static_ok_reference (dlist_old, action, window);
+else if (strcmp (name, "Model") == 0)
+  dlist_new = static_ok_model (dlist_old, action, window);
 else if (strcmp (name, "H") == 0)
   dlist_new = static_ok_h (dlist_old, action, window);
 else if (strcmp (name, "K") == 0)
@@ -960,6 +1085,9 @@ else if (strcmp (name, "K") == 0)
 else if (strcmp (name, "L") == 0)
   dlist_new = static_ok_l (dlist_old, action, window);
 
+else if (strcmp (name, "Net") == 0)
+  dlist_new = static_ok_net (dlist_old, action, window);
+
 else if (strcmp (name, "O1") == 0)
   dlist_new = static_ok_o1 (dlist_old, action, window);
 else if (strcmp (name, "O2") == 0)
@@ -1158,7 +1286,6 @@ GtkWidget *frame;
 GtkWidget *treeview;
 GtkWidget *combo;
 GtkWidget *button;
-GtkWidget *entry;
 GtkWidget *label;
 GtkWidget *hbox_center, *hbox_left;
 GtkWidget *vbox_dialog, *vbox_page, *vbox_top, *vbox_top_top;
@@ -1392,12 +1519,19 @@ gtk_tree_store_set (tree_store, &iter, 0, "Type", -1);
 gtk_tree_store_append (tree_store, &child, &iter);
 gtk_tree_store_set (tree_store, &child, 0, "Reference", -1);
 gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Model", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
 gtk_tree_store_set (tree_store, &child, 0, "H", -1);
 gtk_tree_store_append (tree_store, &child, &iter);
 gtk_tree_store_set (tree_store, &child, 0, "K", -1);
 gtk_tree_store_append (tree_store, &child, &iter);
 gtk_tree_store_set (tree_store, &child, 0, "L", -1);
 
+gtk_tree_store_append (tree_store, &iter, NULL);
+gtk_tree_store_set (tree_store, &iter, 0, "Projection", -1);
+gtk_tree_store_append (tree_store, &child, &iter);
+gtk_tree_store_set (tree_store, &child, 0, "Net", -1);
+
 gtk_tree_store_append (tree_store, &iter, NULL);
 gtk_tree_store_set (tree_store, &iter, 0, "Scope", -1);
 gtk_tree_store_append (tree_store, &child, &iter);
@@ -1457,12 +1591,13 @@ hbox_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
-entry = gtk_entry_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left), entry, FALSE, FALSE, 0);
-gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_10);
-gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_10);
-g_object_set_data (G_OBJECT (dialog), "widget_min", entry);
-gtk_widget_show (entry);
+/**********************************************
+ * this widget will be removed in static_init *
+ **********************************************/
+
+combo = gtk_combo_box_new ();
+gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "widget_min", combo);
 
 /*******
  * Max *
@@ -1480,12 +1615,13 @@ hbox_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
-entry = gtk_entry_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left), entry, FALSE, FALSE, 0);
-gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_10);
-gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_10);
-g_object_set_data (G_OBJECT (dialog), "widget_max", entry);
-gtk_widget_show (entry);
+/**********************************************
+ * this widget will be removed in static_init *
+ **********************************************/
+
+combo = gtk_combo_box_new ();
+gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "widget_max", combo);
 
 /*********************
  * Ok/Cancel buttons *
