@@ -671,8 +671,8 @@ GtkWidget *dialog = window->dialog0;
 GtkWidget* button;
 
 /*******************************************
- *  * link data: execute global or local task *
- *   *******************************************/
+ * link data: execute global or local task *
+ *******************************************/
 
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
@@ -768,19 +768,10 @@ GtkWidget *entry;
 gamgi_bool global;
 const char *name;
 
-/***********************************************
- * global selection can be used only to select *
- * the second object, not the main object(s)   *
- ***********************************************/
-
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_text");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE &&
-gamgi_io_token_check (name) == FALSE && 
-window_dialog != window_mouse) return;
-
 /***********************************************
  * global selection can be used only to select *
  * the second object, not the main object      *
