@@ -21,7 +21,7 @@ static void static_list (GtkWidget *widget, void *data);
 
 static gamgi_bool static_grab (gamgi_window *window);
 
-static void static_apply (gamgi_window *window_mouse, gamgi_window *window_dialog);
+static gamgi_bool static_apply (gamgi_window *window_mouse, gamgi_window *window_dialog);
 
 static void static_ok_global (gamgi_window *window_dialog);
 
