@@ -349,7 +349,7 @@ gamgi_window *window = GAMGI_CAST_WINDOW data;
  *     remove window     *
  *************************/
 
-gamgi_gtk_gamgi_exit_dialogs ();
+gamgi_gtk_dialog_global_remove ();
 
 gamgi_gtk_window_remove_apply (window);
 }
