@@ -101,8 +101,8 @@ GAMGI_IO_DEJAVU_MONO_ITALIC, GAMGI_IO_DEJAVU_MONO_BOLD_ITALIC };
  * the Gamgi->About GUI dialog *
  *******************************/
 
-#define GAMGI_IO_DATE "31st October 2013"
-#define GAMGI_IO_VERSION "0.16.8"
+#define GAMGI_IO_DATE "20th December 2013"
+#define GAMGI_IO_VERSION "0.17+"
 #define GAMGI_IO_AUTHORS "Carlos Pereira et al."
 #define GAMGI_IO_LICENSE "GPL"
 #define GAMGI_IO_WEBSITE "http://www.gamgi.org/"
