@@ -533,7 +533,7 @@ if (direction->loops[0] != 0)
   gamgi->gamgi->length, direction->origin[2]);
   gamgi_io_file_fprintf (fp, string, error);
 		
-  if (direction->type == GAMGI_PHYS_LINE)
+  if (direction->model == GAMGI_PHYS_LINE)
     {
     /******************************
      * render direction as a line *
@@ -565,7 +565,7 @@ if (direction->loops[0] != 0)
     gamgi_io_file_fprintf (fp, "</Shape>\n", error);
     gamgi_io_file_fprintf (fp, "</Transform>\n", error);
     }
-  else if (direction->type == GAMGI_PHYS_POLE)
+  else if (direction->model == GAMGI_PHYS_POLE)
     {
     /*****************************************************************
      * stereographic projection: render direction as a chess bitmask *
@@ -576,7 +576,7 @@ if (direction->loops[0] != 0)
     color[2] = direction->blue;
     gamgi_io_x3d_render_chess (fp, direction->loops[0], direction->points, color, error);
     }
-  else if (direction->type == GAMGI_PHYS_TRACE)
+  else if (direction->model == GAMGI_PHYS_TRACE)
     {
     /*********************************************************
      * stereographic projection: render direction as an arch *
@@ -635,7 +635,7 @@ static_scale (fp, plane->object.scale, plane->center, error);
 
 if (plane->loops[0] != 0)
   {
-  if (plane->type == GAMGI_PHYS_VECTOR)
+  if (plane->model == GAMGI_PHYS_VECTOR)
     {
     /*******************************************************
      * reciprocal lattice: render plane as a cross bitmask *
@@ -654,7 +654,7 @@ if (plane->loops[0] != 0)
     gamgi->gamgi->length, plane->origin[2]);
     gamgi_io_file_fprintf (fp, string, error);
 			
-    if (plane->type == GAMGI_PHYS_POLYGON)
+    if (plane->model == GAMGI_PHYS_POLYGON)
       {
       /*****************************
        * render plane as a polygon *
@@ -689,7 +689,7 @@ if (plane->loops[0] != 0)
       gamgi_io_file_fprintf(fp, "</Shape>\n", error);
       gamgi_io_file_fprintf(fp, "</Transform>\n", error);
       }
-    else if (plane->type == GAMGI_PHYS_POLE)
+    else if (plane->model == GAMGI_PHYS_POLE)
       {
       /*************************************************************
        * stereographic projection: render plane as a cross bitmask *
@@ -700,7 +700,7 @@ if (plane->loops[0] != 0)
       color[2] = plane->blue;
       gamgi_io_x3d_render_cross (fp, plane->loops[0], plane->points, color, error);
       }
-    else if (plane->type == GAMGI_PHYS_TRACE)
+    else if (plane->model == GAMGI_PHYS_TRACE)
       {
       /*****************************************************
        * stereographic projection: render plane as an arch *
@@ -1012,7 +1012,7 @@ gamgi->gamgi->length, cell->origin[1],
 gamgi->gamgi->length, cell->origin[2]);
 gamgi_io_file_fprintf (fp, string, error);
 	
-if (cell->type != GAMGI_PHYS_PROJECTION)
+if (cell->model != GAMGI_PHYS_PROJECTION)
   {
   gamgi_math_quaternion_to_axis (cell->quaternion, &phi, axis);
   sprintf (string, "<Transform rotation=\"%.*f %.*f %.*f %.*f\">\n", 
@@ -1031,8 +1031,8 @@ glGetFloatv (GL_COLOR_CLEAR_VALUE, background);
 
 if (cell->loops != NULL && cell->borders != FALSE && 
 (cell->lattice != GAMGI_PHYS_HEXAGONAL_P || 
-(cell->type != GAMGI_PHYS_WIGNER && cell->type != GAMGI_PHYS_CONVENTIONAL)) &&
-(cell->lattice != GAMGI_PHYS_ORTHORHOMBIC_C || cell->type != GAMGI_PHYS_WIGNER))
+(cell->model != GAMGI_PHYS_WIGNER && cell->model != GAMGI_PHYS_CONVENTIONAL)) &&
+(cell->lattice != GAMGI_PHYS_ORTHORHOMBIC_C || cell->model != GAMGI_PHYS_WIGNER))
   {
   gamgi_io_file_fprintf (fp, "<Shape>\n<Appearance>\n", error);
 
@@ -1120,7 +1120,7 @@ if (cell->faces == TRUE)
 if (cell->nodes == TRUE)
   gamgi_io_x3d_render_points (fp, cell->n_nodes, cell->points, color,error);
 
-if (cell->type != GAMGI_PHYS_PROJECTION)
+if (cell->model != GAMGI_PHYS_PROJECTION)
   gamgi_io_file_fprintf (fp, "</Transform>\n", error);
 	
 gamgi_io_file_fprintf (fp, "</Transform>\n", error);
