@@ -13,8 +13,6 @@
 #include "gamgi_math.h"
 #include "gamgi_phys.h"
 
-#include "gamgi_mesa_rotate.h"
-#include "gamgi_mesa_translate.h"
 #include "gamgi_math_vector.h"
 #include "gamgi_math_matrix.h"
 #include "gamgi_math_quaternion.h"
