@@ -252,6 +252,72 @@ void gamgi_math_position_text_translation_get (gamgi_text *text, double *origin)
 gamgi_math_vector_copy (text->origin, origin);
 }
 
+void gamgi_math_position_orbital_rotation_set (gamgi_orbital *orbital, double *euler)
+{
+double matrix[9], inverse[9], rotate[9];
+double quaternion[4];
+double center[3];
+ 
+gamgi_math_vector_zero (center);
+
+/**********************************************
+ * rotate orbital backward, to properly reset *
+ * rotation, updating also origin and center  *
+ **********************************************/
+  
+gamgi_math_quaternion_to_matrix (orbital->quaternion, matrix);
+gamgi_math_matrix_inverse (matrix, inverse);
+gamgi_math_quaternion_from_matrix (inverse, quaternion);
+gamgi_mesa_rotate_orbital (orbital, quaternion, inverse, center);
+
+/****************************************************************
+ * rotate orbital foward, to update orbital origin and center   *
+ *                                                              *
+ * backward and forward rotations are applied around an         *
+ * arbitrary point center, as these operations will change      *
+ * the orbital origin accordingly, which is then used in the    *
+ * translation applied next to properly positionate the orbital *
+ ****************************************************************/
+
+gamgi_math_euler_to_matrix (euler, rotate);
+gamgi_math_quaternion_from_matrix (rotate, quaternion);
+gamgi_mesa_rotate_orbital (orbital, quaternion, rotate, center);
+
+/*****************************************************
+ * rotation must be done before translation,         *
+ * to guarantee that origin will have the            *
+ * defined origin coordinates. As rotation is done   *
+ * around the center, the origin coordinates will    *
+ * change. The translation then corrects this shift. *
+ *****************************************************/
+}
+
+void gamgi_math_position_orbital_rotation_get (gamgi_orbital *orbital, double *euler)
+{
+double rotate[9];
+
+gamgi_math_quaternion_to_matrix (orbital->quaternion, rotate);
+gamgi_math_euler_from_matrix (rotate, euler);
+}
+
+void gamgi_math_position_orbital_translation_set (gamgi_orbital *orbital, double *origin)
+{
+double translate[3];
+
+/********************************************************************
+ * correct the orbital origin change due to the previous rotation:  *
+ * as this is applied around the orbital center, the origin changes *
+ ********************************************************************/
+
+gamgi_math_vector_sub (origin, orbital->origin, translate);
+gamgi_mesa_translate_orbital (orbital, translate);
+}
+
+void gamgi_math_position_orbital_translation_get (gamgi_orbital *orbital, double *origin)
+{
+gamgi_math_vector_copy (orbital->origin, origin);
+}
+
 void gamgi_math_position_direction_rotation_set (gamgi_direction *direction, 
 double *euler)
 {
