@@ -14,7 +14,7 @@
 
 
 typedef void (*gamgi_tesselation) ();
-typedef void (*gamgi_projection) (double *, double *);
+typedef void (*gamgi_net) (double *, double *);
 
 /********** enumerations **********
  **********************************/
