@@ -145,10 +145,12 @@ GdkEventConfigure *event, void *data)
 {
 GdkGLDrawable *gldrawable = gtk_widget_get_gl_drawable (widget);
 GdkGLContext *glcontext = gtk_widget_get_gl_context (widget);
+GtkAllocation allocation;
 
 if (gdk_gl_drawable_gl_begin (gldrawable, glcontext) == TRUE)
   {
-  glViewport (0, 0, widget->allocation.width, widget->allocation.height);
+  gtk_widget_get_allocation (widget, &allocation);
+  glViewport (0, 0, allocation.width, allocation.height);
   gdk_gl_drawable_gl_end (gldrawable);
   }
 
@@ -183,6 +185,7 @@ gamgi_bool gamgi_mesa_area_press (GtkWidget *widget,
 GdkEventButton *event, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
+GtkAllocation allocation;
 int x, y;
 
 /*************************************
@@ -191,7 +194,8 @@ int x, y;
  *************************************/
 
 x = event->x;
-y = widget->allocation.height - event->y;
+gtk_widget_get_allocation (widget, &allocation);
+y = allocation.height - event->y;
 
 /******************************
  * handle rectangle selection *
@@ -222,6 +226,7 @@ return TRUE;
 gamgi_bool gamgi_mesa_area_release (GtkWidget *widget,
 GdkEventButton *event, void *data)
 {
+GtkAllocation allocation;
 int x, y;
 
 /*************************************
@@ -230,7 +235,8 @@ int x, y;
  *************************************/
 
 x = event->x;
-y = widget->allocation.height - event->y;
+gtk_widget_get_allocation (widget, &allocation);
+y = allocation.height - event->y;
 
 /*************************************
  * OpenGL puts origin at the bottom, *
@@ -248,10 +254,10 @@ GdkEventMotion *event, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GdkModifierType state;
-int width = widget->allocation.width;
-int height = widget->allocation.height;
+GtkAllocation allocation;
 double axis[3], translate[3];
 double angle, scale;
+int width, height;
 int x, y; 
 
 if (event->is_hint) gdk_window_get_pointer (event->window, &x, &y, &state);
@@ -262,6 +268,10 @@ else
   state = event->state;
   }
 
+gtk_widget_get_allocation (widget, &allocation);
+width = allocation.width;
+height = allocation.height;
+
 /***********************************
  * handle selection rectangle drag *
  ***********************************/
