@@ -568,7 +568,7 @@ if (class == GAMGI_ENGINE_DIRECTION)
 
 glPushMatrix ();
 
-if (direction->type == GAMGI_PHYS_LINE)
+if (direction->model == GAMGI_PHYS_LINE)
   {
   glTranslatef (direction->center[0], direction->center[1], direction->center[2]);
   glScalef (direction->object.scale, direction->object.scale, direction->object.scale);
@@ -584,7 +584,7 @@ if (class >= GAMGI_ENGINE_DIRECTION)
   glPushMatrix ();
   
   glTranslatef (direction->origin[0], direction->origin[1], direction->origin[2]);
-  if (direction->type == GAMGI_PHYS_LINE)
+  if (direction->model == GAMGI_PHYS_LINE)
     {
     gamgi_math_quaternion_to_matrix4 (direction->quaternion, rotate);
     glMultMatrixd (rotate);
@@ -593,12 +593,12 @@ if (class >= GAMGI_ENGINE_DIRECTION)
     gamgi_mesa_render_lines (direction->loops, direction->points);
     glLineWidth (1.0);
     }
-  else if (direction->type == GAMGI_PHYS_POLE)
+  else if (direction->model == GAMGI_PHYS_POLE)
     {
     gamgi_mesa_render_points_chess (direction->loops[0],
     direction->points, GAMGI_MESA_POLE_WIDTH * direction->object.scale);
     }
-  else if (direction->type == GAMGI_PHYS_TRACE)
+  else if (direction->model == GAMGI_PHYS_TRACE)
     {
     glLineWidth (GAMGI_MESA_TRACE_WIDTH * direction->object.scale);
     gamgi_mesa_render_line_strip (direction->loops[0], direction->points);
@@ -682,7 +682,7 @@ if (class == GAMGI_ENGINE_PLANE)
 
 glPushMatrix ();
 
-if (plane->type == GAMGI_PHYS_POLYGON)
+if (plane->model == GAMGI_PHYS_POLYGON)
   {
   glTranslatef (plane->center[0], plane->center[1], plane->center[2]);
   glScalef (plane->object.scale, plane->object.scale, plane->object.scale);
@@ -697,7 +697,7 @@ if (class >= GAMGI_ENGINE_PLANE)
   {
   glPushMatrix ();
 
-  if (plane->type == GAMGI_PHYS_VECTOR)
+  if (plane->model == GAMGI_PHYS_VECTOR)
     {
     gamgi_mesa_render_points_cross (plane->loops[0],
     plane->origin, GAMGI_MESA_POLE_WIDTH * plane->object.scale);
@@ -705,7 +705,7 @@ if (class >= GAMGI_ENGINE_PLANE)
   else
     {
     glTranslatef (plane->origin[0], plane->origin[1], plane->origin[2]);
-    if (plane->type == GAMGI_PHYS_POLYGON)
+    if (plane->model == GAMGI_PHYS_POLYGON)
       {
       gamgi_math_quaternion_to_matrix4 (plane->quaternion, rotate);
       glMultMatrixd (rotate);
@@ -717,13 +717,13 @@ if (class >= GAMGI_ENGINE_PLANE)
       glEnable(GL_CULL_FACE);
       }
 
-    else if (plane->type == GAMGI_PHYS_POLE)
+    else if (plane->model == GAMGI_PHYS_POLE)
       {
       gamgi_mesa_render_points_cross (plane->loops[0],
       plane->points, GAMGI_MESA_POLE_WIDTH * plane->object.scale);
       }
 
-    else if (plane->type == GAMGI_PHYS_TRACE)
+    else if (plane->model == GAMGI_PHYS_TRACE)
       {
       glLineWidth (GAMGI_MESA_TRACE_WIDTH * plane->object.scale);
       gamgi_mesa_render_line_strip (plane->loops[0], plane->points);
@@ -1269,7 +1269,7 @@ if (class >= GAMGI_ENGINE_CELL)
   glPushMatrix ();
 
   glTranslatef (cell->origin[0], cell->origin[1], cell->origin[2]);
-  if (cell->type != GAMGI_PHYS_PROJECTION)
+  if (cell->model != GAMGI_PHYS_PROJECTION)
     {
     gamgi_math_quaternion_to_matrix4 (cell->quaternion, rotate);
     glMultMatrixd (rotate);
@@ -1296,8 +1296,8 @@ if (class >= GAMGI_ENGINE_CELL)
 
   if (cell->loops != NULL && cell->borders != FALSE &&
   (cell->lattice != GAMGI_PHYS_HEXAGONAL_P ||
-  (cell->type != GAMGI_PHYS_WIGNER && cell->type != GAMGI_PHYS_CONVENTIONAL)) &&
-  (cell->lattice != GAMGI_PHYS_ORTHORHOMBIC_C || cell->type != GAMGI_PHYS_WIGNER))
+  (cell->model != GAMGI_PHYS_WIGNER && cell->model != GAMGI_PHYS_CONVENTIONAL)) &&
+  (cell->lattice != GAMGI_PHYS_ORTHORHOMBIC_C || cell->model != GAMGI_PHYS_WIGNER))
     gamgi_mesa_render_loops (cell->loops, cell->points);
 
   if (cell->nodes == TRUE)
