@@ -145,6 +145,9 @@ while (n_points-- > 0)
 
 void gamgi_mesa_render_points_cross (int n_points, double *points, int width)
 {
+glPushMatrix ();
+glTranslatef (0.0, 0.0, GAMGI_MESA_OFFSET_BITMAP);
+
 if (width > 5) width = 5;
 if (width < 1) width = 1;
 
@@ -170,10 +173,15 @@ switch (width)
   static_mask (n_points, points, width, cross5);
   break;
   }
+
+glPopMatrix ();
 }
 
 void gamgi_mesa_render_points_chess (int n_points, double *points, int width)
 {
+glPushMatrix ();
+glTranslatef (0.0, 0.0, GAMGI_MESA_OFFSET_BITMAP);
+
 if (width > 5) width = 5;
 if (width < 1) width = 1;
 
@@ -199,6 +207,8 @@ switch (width)
   static_mask (n_points, points, width, chess5);
   break;
   }
+
+glPopMatrix ();
 }
 
 void gamgi_mesa_render_points (int n_points, double *points)
