@@ -26,6 +26,7 @@
 #include "gamgi_gtk_text_remove.h"
 #include "gamgi_gtk_orbital_create.h"
 #include "gamgi_gtk_orbital_copy.h"
+#include "gamgi_gtk_orbital_select.h"
 #include "gamgi_gtk_orbital_link.h"
 #include "gamgi_gtk_orbital_modify.h"
 #include "gamgi_gtk_orbital_remove.h"
@@ -287,7 +288,6 @@ do
    **********************************************************************/
 
   color = b1 * g1 * rgb[3*i]/r0 + b1 * rgb[3*i+1]/g0 + rgb[3*i+2]/b0;
-
   if (color == 0 || levels[color - 1] == level) continue;
 
   levels[color - 1] = level; 
@@ -571,6 +571,45 @@ do
 gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, 1, 0);
 }
 
+static gamgi_bool static_box (int *box, gamgi_window *window)
+{
+GtkAllocation allocation;
+int width, height;
+
+/***********************************************
+ * box[0], box[1]: below left x,y coordinates  *
+ * box[2], box[3]: above right x,y coordinates *
+ ***********************************************/
+
+/*******************************
+ * get graphic area dimensions *
+ *******************************/
+
+gtk_widget_get_allocation (window->area, &allocation);
+width = allocation.width;
+height = allocation.height;
+
+/**************************************************
+ * the box is completely outside the graphic area *
+ **************************************************/
+
+if (box[0] > width - 1) return FALSE;
+if (box[1] > height - 1) return FALSE;
+if (box[2] < 0) return FALSE;
+if (box[3] < 0) return FALSE;
+
+/*************************************************
+ * the box is partially outside the graphic area *
+ *************************************************/
+
+if (box[0] < 0) box[0] = 0;
+if (box[1] < 0) box[1] = 0;
+if (box[2] > width - 1) box[2] = width - 1;
+if (box[3] > height - 1) box[3] = height - 1;
+
+return TRUE;
+}
+
 gamgi_window *gamgi_mesa_select_window (void)
 {
 gamgi_window *window;
@@ -639,6 +678,7 @@ switch (window_dialog->action)
   return TRUE;
 
   case GAMGI_GTK_ORBITAL_SELECT:
+  gamgi_gtk_orbital_select_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_ORBITAL_LINK:
@@ -1049,6 +1089,13 @@ gamgi_slist *slist;
 if (class == GAMGI_ENGINE_GAMGI || class == GAMGI_ENGINE_WINDOW ||
 class == GAMGI_ENGINE_LAYER || class == GAMGI_ENGINE_LIGHT) return NULL;
 
+/*************************************************************
+ * make sure the sampling box is entirely inside the graphic *
+ * area (return NULL only when the box is entirely outside)  *
+ *************************************************************/
+
+if (static_box (box, window_mouse) == FALSE) return NULL;
+
 /********************************************************
  * grab objects in selected rectangle that are in scope *
  ********************************************************/
