@@ -321,7 +321,7 @@ for (n = 0; n < n_positions; n++)
    * for all nodes, because it is under the border tolerance.      *
    *****************************************************************/
 
-  if (cell->type == GAMGI_PHYS_WIGNER)
+  if (cell->model == GAMGI_PHYS_WIGNER)
     gamgi_math_cell_range_positive (relative + 3*n, relative + 3*n);
   else
     gamgi_math_cell_range_half (relative + 3*n, relative + 3*n);
@@ -394,7 +394,7 @@ n1 = cell->n1;
 n2 = cell->n2;
 n3 = cell->n3;
 
-switch (cell->type)
+switch (cell->model)
   {
   case GAMGI_PHYS_CONVENTIONAL:
   if (cell->lattice == GAMGI_PHYS_HEXAGONAL_P)
@@ -510,7 +510,7 @@ int *replicas)
 {
 double relative[3];
 
-switch (cell->type)
+switch (cell->model)
   {
   case GAMGI_PHYS_CONVENTIONAL: 
   case GAMGI_PHYS_PRIMITIVE: 
@@ -751,7 +751,7 @@ for (i = 0; i < n_nodes; i++)
       inverse, i, j, replicas) == FALSE) continue;
   
       if (cell->lattice == GAMGI_PHYS_HEXAGONAL_P &&
-      cell->type == GAMGI_PHYS_CONVENTIONAL && 
+      cell->model == GAMGI_PHYS_CONVENTIONAL && 
       static_inside_triangles (cell, i, relative + 3*j, 
       index, triangles) == FALSE) continue;
       }
@@ -1907,7 +1907,7 @@ int n_nodes;
 
 n1 = cell->n1; n2 = cell->n2; n3 = cell->n3;
 
-if (cell->type == GAMGI_PHYS_CONVENTIONAL)
+if (cell->model == GAMGI_PHYS_CONVENTIONAL)
   gamgi_math_node_conventional (cell->lattice, 
   cell->o1, cell->o2, cell->o3, &o1, &o2, &o3, &o4);
 else
@@ -2212,7 +2212,7 @@ static_volume (cell, inverse);
  * 4) object-cutoff and Wigner-Seitz volumes                *
  ************************************************************/
 
-switch (cell->type)
+switch (cell->model)
   {
   case GAMGI_PHYS_CONVENTIONAL: 
 
