@@ -101,7 +101,7 @@ static void static_generate (double *input, const char **wyckoff,
 int start, int n_positions, double *positions)
 {
 int i;
-char token[20];
+char token[GAMGI_ENGINE_STRING];
 char *token_a, *token_b, *token_c;
 
 for (i = 0; i < n_positions; i++)
